Class: Aws::Kafka::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Kafka::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kafka/client.rb,
sig/client.rbs
Overview
An API client for Kafka. To construct a client, you need to configure a :region and :credentials.
client = Aws::Kafka::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchAssociateScramSecretResponseSuccess, _BatchDisassociateScramSecretResponseSuccess, _CreateClusterResponseSuccess, _CreateClusterV2ResponseSuccess, _CreateConfigurationResponseSuccess, _CreateReplicatorResponseSuccess, _CreateTopicResponseSuccess, _CreateVpcConnectionResponseSuccess, _DeleteClusterPolicyResponseSuccess, _DeleteClusterResponseSuccess, _DeleteConfigurationResponseSuccess, _DeleteReplicatorResponseSuccess, _DeleteTopicResponseSuccess, _DeleteVpcConnectionResponseSuccess, _DescribeClusterOperationResponseSuccess, _DescribeClusterOperationV2ResponseSuccess, _DescribeClusterResponseSuccess, _DescribeClusterV2ResponseSuccess, _DescribeConfigurationResponseSuccess, _DescribeConfigurationRevisionResponseSuccess, _DescribeReplicatorResponseSuccess, _DescribeTopicPartitionsResponseSuccess, _DescribeTopicResponseSuccess, _DescribeVpcConnectionResponseSuccess, _GetBootstrapBrokersResponseSuccess, _GetClusterPolicyResponseSuccess, _GetCompatibleKafkaVersionsResponseSuccess, _ListClientVpcConnectionsResponseSuccess, _ListClusterOperationsResponseSuccess, _ListClusterOperationsV2ResponseSuccess, _ListClustersResponseSuccess, _ListClustersV2ResponseSuccess, _ListConfigurationRevisionsResponseSuccess, _ListConfigurationsResponseSuccess, _ListKafkaVersionsResponseSuccess, _ListNodesResponseSuccess, _ListReplicatorsResponseSuccess, _ListScramSecretsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTopicsResponseSuccess, _ListVpcConnectionsResponseSuccess, _PutClusterPolicyResponseSuccess, _RebootBrokerResponseSuccess, _RejectClientVpcConnectionResponseSuccess, _UpdateBrokerCountResponseSuccess, _UpdateBrokerStorageResponseSuccess, _UpdateBrokerTypeResponseSuccess, _UpdateClusterConfigurationResponseSuccess, _UpdateClusterKafkaVersionResponseSuccess, _UpdateConfigurationResponseSuccess, _UpdateConnectivityResponseSuccess, _UpdateMonitoringResponseSuccess, _UpdateRebalancingResponseSuccess, _UpdateReplicationInfoResponseSuccess, _UpdateSecurityResponseSuccess, _UpdateStorageResponseSuccess, _UpdateTopicResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_associate_scram_secret(params = {}) ⇒ Types::BatchAssociateScramSecretResponse
Associates one or more Scram Secrets with an Amazon MSK cluster.
-
#batch_disassociate_scram_secret(params = {}) ⇒ Types::BatchDisassociateScramSecretResponse
Disassociates one or more Scram Secrets from an Amazon MSK cluster.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a new MSK cluster.
-
#create_cluster_v2(params = {}) ⇒ Types::CreateClusterV2Response
Creates a new Amazon MSK cluster of either the provisioned or the serverless type.
-
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new MSK configuration.
-
#create_replicator(params = {}) ⇒ Types::CreateReplicatorResponse
Creates a new Kafka Replicator.
-
#create_topic(params = {}) ⇒ Types::CreateTopicResponse
Creates a topic in the specified MSK cluster.
-
#create_vpc_connection(params = {}) ⇒ Types::CreateVpcConnectionResponse
Creates a new Amazon MSK VPC connection.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the request.
-
#delete_cluster_policy(params = {}) ⇒ Struct
Deletes the MSK cluster policy specified by the Amazon Resource Name (ARN) in your request.
-
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified MSK configuration.
-
#delete_replicator(params = {}) ⇒ Types::DeleteReplicatorResponse
Deletes a replicator.
-
#delete_topic(params = {}) ⇒ Types::DeleteTopicResponse
Deletes a topic in the specified MSK cluster.
-
#delete_vpc_connection(params = {}) ⇒ Types::DeleteVpcConnectionResponse
Deletes the Amazon MSK VPC connection specified in your request.
-
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.
-
#describe_cluster_operation(params = {}) ⇒ Types::DescribeClusterOperationResponse
Returns a description of the cluster operation specified by the ARN.
-
#describe_cluster_operation_v2(params = {}) ⇒ Types::DescribeClusterOperationV2Response
Returns a description of the cluster operation specified by the ARN.
-
#describe_cluster_v2(params = {}) ⇒ Types::DescribeClusterV2Response
Returns a description of the MSK cluster of either the provisioned or the serverless type whose Amazon Resource Name (ARN) is specified in the request.
-
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns a description of this MSK configuration.
-
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns a description of this revision of the configuration.
-
#describe_replicator(params = {}) ⇒ Types::DescribeReplicatorResponse
Returns a description of the Kafka Replicator whose Amazon Resource Name (ARN) is specified in the request.
-
#describe_topic(params = {}) ⇒ Types::DescribeTopicResponse
Returns topic details of this topic on a MSK cluster.
-
#describe_topic_partitions(params = {}) ⇒ Types::DescribeTopicPartitionsResponse
Returns partition details of this topic on a MSK cluster.
-
#describe_vpc_connection(params = {}) ⇒ Types::DescribeVpcConnectionResponse
Displays information about the specified Amazon MSK VPC connection.
-
#get_bootstrap_brokers(params = {}) ⇒ Types::GetBootstrapBrokersResponse
A list of brokers that a client application can use to bootstrap.
-
#get_cluster_policy(params = {}) ⇒ Types::GetClusterPolicyResponse
Retrieves the contents of the specified MSK cluster policy.
-
#get_compatible_kafka_versions(params = {}) ⇒ Types::GetCompatibleKafkaVersionsResponse
Gets the Apache Kafka versions to which you can update the MSK cluster.
-
#list_client_vpc_connections(params = {}) ⇒ Types::ListClientVpcConnectionsResponse
Displays a list of client VPC connections.
-
#list_cluster_operations(params = {}) ⇒ Types::ListClusterOperationsResponse
Returns a list of all the operations that have been performed on the specified MSK cluster.
-
#list_cluster_operations_v2(params = {}) ⇒ Types::ListClusterOperationsV2Response
Returns a list of all the operations that have been performed on the specified MSK cluster.
-
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns a list of all the MSK clusters in the current Region.
-
#list_clusters_v2(params = {}) ⇒ Types::ListClustersV2Response
Returns a list of all the MSK clusters in the current Region.
-
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all the revisions of an MSK configuration.
-
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all the MSK configurations in this Region.
-
#list_kafka_versions(params = {}) ⇒ Types::ListKafkaVersionsResponse
Returns a list of Apache Kafka versions.
-
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Returns a list of the broker nodes in the cluster.
-
#list_replicators(params = {}) ⇒ Types::ListReplicatorsResponse
Lists the replicators.
-
#list_scram_secrets(params = {}) ⇒ Types::ListScramSecretsResponse
Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags associated with the specified resource.
-
#list_topics(params = {}) ⇒ Types::ListTopicsResponse
List topics in a MSK cluster.
-
#list_vpc_connections(params = {}) ⇒ Types::ListVpcConnectionsResponse
Displays a list of Amazon MSK VPC connections.
-
#put_cluster_policy(params = {}) ⇒ Types::PutClusterPolicyResponse
Creates or updates the specified MSK cluster policy.
-
#reboot_broker(params = {}) ⇒ Types::RebootBrokerResponse
Executes a reboot on a broker.
-
#reject_client_vpc_connection(params = {}) ⇒ Struct
Returns an empty response.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified MSK resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tags associated with the keys that are provided in the query.
-
#update_broker_count(params = {}) ⇒ Types::UpdateBrokerCountResponse
Updates the number of broker nodes in the cluster.
-
#update_broker_storage(params = {}) ⇒ Types::UpdateBrokerStorageResponse
Updates the EBS storage associated with MSK brokers.
-
#update_broker_type(params = {}) ⇒ Types::UpdateBrokerTypeResponse
Updates all the brokers in the cluster to the specified type.
-
#update_cluster_configuration(params = {}) ⇒ Types::UpdateClusterConfigurationResponse
Updates the cluster with the configuration that is specified in the request body.
-
#update_cluster_kafka_version(params = {}) ⇒ Types::UpdateClusterKafkaVersionResponse
Updates the Apache Kafka version for the cluster.
-
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates an existing MSK configuration.
-
#update_connectivity(params = {}) ⇒ Types::UpdateConnectivityResponse
Updates the connectivity configuration for the MSK cluster.
-
#update_monitoring(params = {}) ⇒ Types::UpdateMonitoringResponse
Updates the monitoring settings for the cluster.
-
#update_rebalancing(params = {}) ⇒ Types::UpdateRebalancingResponse
Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.
-
#update_replication_info(params = {}) ⇒ Types::UpdateReplicationInfoResponse
Updates replication info of a replicator.
-
#update_security(params = {}) ⇒ Types::UpdateSecurityResponse
You can use this operation to update the encrypting and authentication settings for an existing cluster.
-
#update_storage(params = {}) ⇒ Types::UpdateStorageResponse
Updates cluster broker volume size (or) sets cluster storage mode to TIERED.
-
#update_topic(params = {}) ⇒ Types::UpdateTopicResponse
Updates the topic configuration or partition count in the specified MSK cluster.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-kafka/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3877 3878 3879 |
# File 'lib/aws-sdk-kafka/client.rb', line 3877 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3880 3881 3882 |
# File 'lib/aws-sdk-kafka/client.rb', line 3880 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_associate_scram_secret(params = {}) ⇒ Types::BatchAssociateScramSecretResponse
Associates one or more Scram Secrets with an Amazon MSK cluster.
87 |
# File 'sig/client.rbs', line 87
def batch_associate_scram_secret: (
|
#batch_disassociate_scram_secret(params = {}) ⇒ Types::BatchDisassociateScramSecretResponse
Disassociates one or more Scram Secrets from an Amazon MSK cluster.
504 |
# File 'sig/client.rbs', line 504
def batch_disassociate_scram_secret: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 |
# File 'lib/aws-sdk-kafka/client.rb', line 3850 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Kafka') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kafka' context[:gem_version] = '1.116.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a new MSK cluster.
100 |
# File 'sig/client.rbs', line 100
def create_cluster: (
|
#create_cluster_v2(params = {}) ⇒ Types::CreateClusterV2Response
Creates a new Amazon MSK cluster of either the provisioned or the serverless type.
130 |
# File 'sig/client.rbs', line 130
def create_cluster_v2: (
|
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new MSK configuration.
178 |
# File 'sig/client.rbs', line 178
def create_configuration: (
|
#create_replicator(params = {}) ⇒ Types::CreateReplicatorResponse
Creates a new Kafka Replicator.
193 |
# File 'sig/client.rbs', line 193
def create_replicator: (
|
#create_topic(params = {}) ⇒ Types::CreateTopicResponse
Creates a topic in the specified MSK cluster.
266 |
# File 'sig/client.rbs', line 266
def create_topic: (
|
#create_vpc_connection(params = {}) ⇒ Types::CreateVpcConnectionResponse
Creates a new Amazon MSK VPC connection.
287 |
# File 'sig/client.rbs', line 287
def create_vpc_connection: (
|
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the request.
303 |
# File 'sig/client.rbs', line 303
def delete_cluster: (
|
#delete_cluster_policy(params = {}) ⇒ Struct
Deletes the MSK cluster policy specified by the Amazon Resource Name (ARN) in your request.
735 |
# File 'sig/client.rbs', line 735
def delete_cluster_policy: (
|
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified MSK configuration. The configuration must be in the ACTIVE or DELETE_FAILED state.
315 |
# File 'sig/client.rbs', line 315
def delete_configuration: (
|
#delete_replicator(params = {}) ⇒ Types::DeleteReplicatorResponse
Deletes a replicator.
326 |
# File 'sig/client.rbs', line 326
def delete_replicator: (
|
#delete_topic(params = {}) ⇒ Types::DeleteTopicResponse
Deletes a topic in the specified MSK cluster.
339 |
# File 'sig/client.rbs', line 339
def delete_topic: (
|
#delete_vpc_connection(params = {}) ⇒ Types::DeleteVpcConnectionResponse
Deletes the Amazon MSK VPC connection specified in your request.
351 |
# File 'sig/client.rbs', line 351
def delete_vpc_connection: (
|
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.
361 |
# File 'sig/client.rbs', line 361
def describe_cluster: (
|
#describe_cluster_operation(params = {}) ⇒ Types::DescribeClusterOperationResponse
Returns a description of the cluster operation specified by the ARN.
381 |
# File 'sig/client.rbs', line 381
def describe_cluster_operation: (
|
#describe_cluster_operation_v2(params = {}) ⇒ Types::DescribeClusterOperationV2Response
Returns a description of the cluster operation specified by the ARN.
391 |
# File 'sig/client.rbs', line 391
def describe_cluster_operation_v2: (
|
#describe_cluster_v2(params = {}) ⇒ Types::DescribeClusterV2Response
Returns a description of the MSK cluster of either the provisioned or the serverless type whose Amazon Resource Name (ARN) is specified in the request.
371 |
# File 'sig/client.rbs', line 371
def describe_cluster_v2: (
|
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns a description of this MSK configuration.
407 |
# File 'sig/client.rbs', line 407
def describe_configuration: (
|
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns a description of this revision of the configuration.
421 |
# File 'sig/client.rbs', line 421
def describe_configuration_revision: (
|
#describe_replicator(params = {}) ⇒ Types::DescribeReplicatorResponse
Returns a description of the Kafka Replicator whose Amazon Resource Name (ARN) is specified in the request.
445 |
# File 'sig/client.rbs', line 445
def describe_replicator: (
|
#describe_topic(params = {}) ⇒ Types::DescribeTopicResponse
Returns topic details of this topic on a MSK cluster.
460 |
# File 'sig/client.rbs', line 460
def describe_topic: (
|
#describe_topic_partitions(params = {}) ⇒ Types::DescribeTopicPartitionsResponse
Returns partition details of this topic on a MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
472 |
# File 'sig/client.rbs', line 472
def describe_topic_partitions: (
|
#describe_vpc_connection(params = {}) ⇒ Types::DescribeVpcConnectionResponse
Displays information about the specified Amazon MSK VPC connection.
493 |
# File 'sig/client.rbs', line 493
def describe_vpc_connection: (
|
#get_bootstrap_brokers(params = {}) ⇒ Types::GetBootstrapBrokersResponse
A list of brokers that a client application can use to bootstrap. This
list doesn't necessarily include all of the brokers in the cluster.
The following Python 3.6 example shows how you can use the Amazon
Resource Name (ARN) of a cluster to get its bootstrap brokers. If you
don't know the ARN of your cluster, you can use the ListClusters
operation to get the ARNs of all the clusters in this account and
Region.
528 |
# File 'sig/client.rbs', line 528
def get_bootstrap_brokers: (
|
#get_cluster_policy(params = {}) ⇒ Types::GetClusterPolicyResponse
Retrieves the contents of the specified MSK cluster policy.
746 |
# File 'sig/client.rbs', line 746
def get_cluster_policy: (
|
#get_compatible_kafka_versions(params = {}) ⇒ Types::GetCompatibleKafkaVersionsResponse
Gets the Apache Kafka versions to which you can update the MSK cluster.
538 |
# File 'sig/client.rbs', line 538
def get_compatible_kafka_versions: (
|
#list_client_vpc_connections(params = {}) ⇒ Types::ListClientVpcConnectionsResponse
Displays a list of client VPC connections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
688 |
# File 'sig/client.rbs', line 688
def list_client_vpc_connections: (
|
#list_cluster_operations(params = {}) ⇒ Types::ListClusterOperationsResponse
Returns a list of all the operations that have been performed on the specified MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
549 |
# File 'sig/client.rbs', line 549
def list_cluster_operations: (
|
#list_cluster_operations_v2(params = {}) ⇒ Types::ListClusterOperationsV2Response
Returns a list of all the operations that have been performed on the specified MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
562 |
# File 'sig/client.rbs', line 562
def list_cluster_operations_v2: (
|
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns a list of all the MSK clusters in the current Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
575 |
# File 'sig/client.rbs', line 575
def list_clusters: (
|
#list_clusters_v2(params = {}) ⇒ Types::ListClustersV2Response
Returns a list of all the MSK clusters in the current Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
588 |
# File 'sig/client.rbs', line 588
def list_clusters_v2: (
|
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all the revisions of an MSK configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
602 |
# File 'sig/client.rbs', line 602
def list_configuration_revisions: (
|
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all the MSK configurations in this Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
615 |
# File 'sig/client.rbs', line 615
def list_configurations: (
|
#list_kafka_versions(params = {}) ⇒ Types::ListKafkaVersionsResponse
Returns a list of Apache Kafka versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
627 |
# File 'sig/client.rbs', line 627
def list_kafka_versions: (
|
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Returns a list of the broker nodes in the cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
639 |
# File 'sig/client.rbs', line 639
def list_nodes: (
|
#list_replicators(params = {}) ⇒ Types::ListReplicatorsResponse
Lists the replicators.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
652 |
# File 'sig/client.rbs', line 652
def list_replicators: (
|
#list_scram_secrets(params = {}) ⇒ Types::ListScramSecretsResponse
Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
665 |
# File 'sig/client.rbs', line 665
def list_scram_secrets: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags associated with the specified resource.
677 |
# File 'sig/client.rbs', line 677
def list_tags_for_resource: (
|
#list_topics(params = {}) ⇒ Types::ListTopicsResponse
List topics in a MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
713 |
# File 'sig/client.rbs', line 713
def list_topics: (
|
#list_vpc_connections(params = {}) ⇒ Types::ListVpcConnectionsResponse
Displays a list of Amazon MSK VPC connections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
701 |
# File 'sig/client.rbs', line 701
def list_vpc_connections: (
|
#put_cluster_policy(params = {}) ⇒ Types::PutClusterPolicyResponse
Creates or updates the specified MSK cluster policy. If updating the policy, the currentVersion field is required in the request payload.
756 |
# File 'sig/client.rbs', line 756
def put_cluster_policy: (
|
#reboot_broker(params = {}) ⇒ Types::RebootBrokerResponse
Executes a reboot on a broker.
769 |
# File 'sig/client.rbs', line 769
def reboot_broker: (
|
#reject_client_vpc_connection(params = {}) ⇒ Struct
Returns an empty response.
725 |
# File 'sig/client.rbs', line 725
def reject_client_vpc_connection: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified MSK resource.
776 |
# File 'sig/client.rbs', line 776
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the tags associated with the keys that are provided in the query.
783 |
# File 'sig/client.rbs', line 783
def untag_resource: (
|
#update_broker_count(params = {}) ⇒ Types::UpdateBrokerCountResponse
Updates the number of broker nodes in the cluster. You can use this operation to increase the number of brokers in an existing cluster. You can't decrease the number of brokers.
795 |
# File 'sig/client.rbs', line 795
def update_broker_count: (
|
#update_broker_storage(params = {}) ⇒ Types::UpdateBrokerStorageResponse
Updates the EBS storage associated with MSK brokers.
821 |
# File 'sig/client.rbs', line 821
def update_broker_storage: (
|
#update_broker_type(params = {}) ⇒ Types::UpdateBrokerTypeResponse
Updates all the brokers in the cluster to the specified type.
808 |
# File 'sig/client.rbs', line 808
def update_broker_type: (
|
#update_cluster_configuration(params = {}) ⇒ Types::UpdateClusterConfigurationResponse
Updates the cluster with the configuration that is specified in the request body.
856 |
# File 'sig/client.rbs', line 856
def update_cluster_configuration: (
|
#update_cluster_kafka_version(params = {}) ⇒ Types::UpdateClusterKafkaVersionResponse
Updates the Apache Kafka version for the cluster.
872 |
# File 'sig/client.rbs', line 872
def update_cluster_kafka_version: (
|
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates an existing MSK configuration. The configuration must be in the Active state.
843 |
# File 'sig/client.rbs', line 843
def update_configuration: (
|
#update_connectivity(params = {}) ⇒ Types::UpdateConnectivityResponse
Updates the connectivity configuration for the MSK cluster.
889 |
# File 'sig/client.rbs', line 889
def update_connectivity: (
|
#update_monitoring(params = {}) ⇒ Types::UpdateMonitoringResponse
Updates the monitoring settings for the cluster. You can use this operation to specify which Apache Kafka metrics you want Amazon MSK to send to Amazon CloudWatch. You can also specify settings for open monitoring with Prometheus.
905 |
# File 'sig/client.rbs', line 905
def update_monitoring: (
|
#update_rebalancing(params = {}) ⇒ Types::UpdateRebalancingResponse
Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.
920 |
# File 'sig/client.rbs', line 920
def update_rebalancing: (
|
#update_replication_info(params = {}) ⇒ Types::UpdateReplicationInfoResponse
Updates replication info of a replicator.
935 |
# File 'sig/client.rbs', line 935
def update_replication_info: (
|
#update_security(params = {}) ⇒ Types::UpdateSecurityResponse
You can use this operation to update the encrypting and authentication settings for an existing cluster.
965 |
# File 'sig/client.rbs', line 965
def update_security: (
|
#update_storage(params = {}) ⇒ Types::UpdateStorageResponse
Updates cluster broker volume size (or) sets cluster storage mode to TIERED.
979 |
# File 'sig/client.rbs', line 979
def update_storage: (
|
#update_topic(params = {}) ⇒ Types::UpdateTopicResponse
Updates the topic configuration or partition count in the specified MSK cluster.
998 |
# File 'sig/client.rbs', line 998
def update_topic: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3870 3871 3872 |
# File 'lib/aws-sdk-kafka/client.rb', line 3870 def waiter_names [] end |