Class: Aws::Kafka::Types::ApacheKafkaCluster
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ApacheKafkaCluster
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Details of an Apache Kafka Cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apache_kafka_cluster_id ⇒ String
The ID of the Apache Kafka cluster.
-
#bootstrap_broker_string ⇒ String
The bootstrap broker string of the Apache Kafka cluster.
Instance Attribute Details
#apache_kafka_cluster_id ⇒ String
The ID of the Apache Kafka cluster.
39 40 41 42 43 44 |
# File 'lib/aws-sdk-kafka/types.rb', line 39 class ApacheKafkaCluster < Struct.new( :apache_kafka_cluster_id, :bootstrap_broker_string) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string ⇒ String
The bootstrap broker string of the Apache Kafka cluster.
39 40 41 42 43 44 |
# File 'lib/aws-sdk-kafka/types.rb', line 39 class ApacheKafkaCluster < Struct.new( :apache_kafka_cluster_id, :bootstrap_broker_string) SENSITIVE = [] include Aws::Structure end |