Class: Aws::Kafka::Types::AuthorizerLogs
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::AuthorizerLogs
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
The authorizer logs configuration for this MSK cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_logs ⇒ Types::CloudWatchLogs
Details of the CloudWatch Logs destination for authorizer logs.
-
#firehose ⇒ Types::Firehose
Details of the Kinesis Data Firehose delivery stream that is the destination for authorizer logs.
-
#s3 ⇒ Types::S3
Details of the Amazon S3 destination for authorizer logs.
Instance Attribute Details
#cloud_watch_logs ⇒ Types::CloudWatchLogs
Details of the CloudWatch Logs destination for authorizer logs.
63 64 65 66 67 68 69 |
# File 'lib/aws-sdk-kafka/types.rb', line 63 class AuthorizerLogs < Struct.new( :cloud_watch_logs, :firehose, :s3) SENSITIVE = [] include Aws::Structure end |
#firehose ⇒ Types::Firehose
Details of the Kinesis Data Firehose delivery stream that is the destination for authorizer logs.
63 64 65 66 67 68 69 |
# File 'lib/aws-sdk-kafka/types.rb', line 63 class AuthorizerLogs < Struct.new( :cloud_watch_logs, :firehose, :s3) SENSITIVE = [] include Aws::Structure end |
#s3 ⇒ Types::S3
Details of the Amazon S3 destination for authorizer logs.
63 64 65 66 67 68 69 |
# File 'lib/aws-sdk-kafka/types.rb', line 63 class AuthorizerLogs < Struct.new( :cloud_watch_logs, :firehose, :s3) SENSITIVE = [] include Aws::Structure end |