Class: Aws::Kafka::Types::BrokerNodeGroupInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Describes the setup to be used for Apache Kafka broker nodes in the cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#broker_az_distributionString

The distribution of broker nodes across Availability Zones.

Returns:

  • (String)


220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-kafka/types.rb', line 220

class BrokerNodeGroupInfo < Struct.new(
  :broker_az_distribution,
  :client_subnets,
  :instance_type,
  :security_groups,
  :storage_info,
  :connectivity_info,
  :zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#client_subnetsArray<String>

The list of subnets to connect to in the client virtual private cloud (VPC). AWS creates elastic network interfaces inside these subnets. Client applications use elastic network interfaces to produce and consume data. Client subnets can't occupy the Availability Zone with ID use use1-az3.

Returns:

  • (Array<String>)


220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-kafka/types.rb', line 220

class BrokerNodeGroupInfo < Struct.new(
  :broker_az_distribution,
  :client_subnets,
  :instance_type,
  :security_groups,
  :storage_info,
  :connectivity_info,
  :zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#connectivity_infoTypes::ConnectivityInfo

Information about the broker access configuration.



220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-kafka/types.rb', line 220

class BrokerNodeGroupInfo < Struct.new(
  :broker_az_distribution,
  :client_subnets,
  :instance_type,
  :security_groups,
  :storage_info,
  :connectivity_info,
  :zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of broker used in the Amazon MSK cluster.

Returns:

  • (String)


220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-kafka/types.rb', line 220

class BrokerNodeGroupInfo < Struct.new(
  :broker_az_distribution,
  :client_subnets,
  :instance_type,
  :security_groups,
  :storage_info,
  :connectivity_info,
  :zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<String>

The AWS security groups to associate with the elastic network interfaces in order to specify who can connect to and communicate with the Amazon MSK cluster. If you don't specify a security group, Amazon MSK uses the default security group associated with the VPC. If you specify security groups that were shared with you, you must ensure that you have permissions to them. Specifically, you need the ec2:DescribeSecurityGroups permission.

Returns:

  • (Array<String>)


220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-kafka/types.rb', line 220

class BrokerNodeGroupInfo < Struct.new(
  :broker_az_distribution,
  :client_subnets,
  :instance_type,
  :security_groups,
  :storage_info,
  :connectivity_info,
  :zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#storage_infoTypes::StorageInfo

Contains information about storage volumes attached to MSK broker nodes.

Returns:



220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-kafka/types.rb', line 220

class BrokerNodeGroupInfo < Struct.new(
  :broker_az_distribution,
  :client_subnets,
  :instance_type,
  :security_groups,
  :storage_info,
  :connectivity_info,
  :zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#zone_idsArray<String>

The zoneIds for the cluster.

Returns:

  • (Array<String>)


220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-kafka/types.rb', line 220

class BrokerNodeGroupInfo < Struct.new(
  :broker_az_distribution,
  :client_subnets,
  :instance_type,
  :security_groups,
  :storage_info,
  :connectivity_info,
  :zone_ids)
  SENSITIVE = []
  include Aws::Structure
end