Class: Aws::Kafka::Types::Configuration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Represents an MSK Configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the configuration.

Returns:

  • (String)


817
818
819
820
821
822
823
824
825
826
827
# File 'lib/aws-sdk-kafka/types.rb', line 817

class Configuration < Struct.new(
  :arn,
  :creation_time,
  :description,
  :kafka_versions,
  :latest_revision,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time when the configuration was created.

Returns:

  • (Time)


817
818
819
820
821
822
823
824
825
826
827
# File 'lib/aws-sdk-kafka/types.rb', line 817

class Configuration < Struct.new(
  :arn,
  :creation_time,
  :description,
  :kafka_versions,
  :latest_revision,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the configuration.

Returns:

  • (String)


817
818
819
820
821
822
823
824
825
826
827
# File 'lib/aws-sdk-kafka/types.rb', line 817

class Configuration < Struct.new(
  :arn,
  :creation_time,
  :description,
  :kafka_versions,
  :latest_revision,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#kafka_versionsArray<String>

An array of the versions of Apache Kafka with which you can use this MSK configuration. You can use this configuration for an MSK cluster only if the Apache Kafka version specified for the cluster appears in this array.

Returns:

  • (Array<String>)


817
818
819
820
821
822
823
824
825
826
827
# File 'lib/aws-sdk-kafka/types.rb', line 817

class Configuration < Struct.new(
  :arn,
  :creation_time,
  :description,
  :kafka_versions,
  :latest_revision,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#latest_revisionTypes::ConfigurationRevision

Latest revision of the configuration.



817
818
819
820
821
822
823
824
825
826
827
# File 'lib/aws-sdk-kafka/types.rb', line 817

class Configuration < Struct.new(
  :arn,
  :creation_time,
  :description,
  :kafka_versions,
  :latest_revision,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the configuration. Configuration names are strings that match the regex “^[0-9A-Za-z-]+$”.

Returns:

  • (String)


817
818
819
820
821
822
823
824
825
826
827
# File 'lib/aws-sdk-kafka/types.rb', line 817

class Configuration < Struct.new(
  :arn,
  :creation_time,
  :description,
  :kafka_versions,
  :latest_revision,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of a configuration.

Returns:

  • (String)


817
818
819
820
821
822
823
824
825
826
827
# File 'lib/aws-sdk-kafka/types.rb', line 817

class Configuration < Struct.new(
  :arn,
  :creation_time,
  :description,
  :kafka_versions,
  :latest_revision,
  :name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end