Class: Aws::Kafka::Types::ConnectivityInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ConnectivityInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Information about the broker access configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_type ⇒ String
The network type of the cluster, which is IPv4 or DUAL.
-
#public_access ⇒ Types::PublicAccess
Public access control for brokers.
-
#vpc_connectivity ⇒ Types::VpcConnectivity
VpcConnectivity control for brokers.
Instance Attribute Details
#network_type ⇒ String
The network type of the cluster, which is IPv4 or DUAL. The DUAL network type uses both IPv4 and IPv6 addresses for your cluster and its resources.
By default, a cluster uses the IPv4 network type.
928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-kafka/types.rb', line 928 class ConnectivityInfo < Struct.new( :public_access, :vpc_connectivity, :network_type) SENSITIVE = [] include Aws::Structure end |
#public_access ⇒ Types::PublicAccess
Public access control for brokers.
928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-kafka/types.rb', line 928 class ConnectivityInfo < Struct.new( :public_access, :vpc_connectivity, :network_type) SENSITIVE = [] include Aws::Structure end |
#vpc_connectivity ⇒ Types::VpcConnectivity
VpcConnectivity control for brokers.
928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-kafka/types.rb', line 928 class ConnectivityInfo < Struct.new( :public_access, :vpc_connectivity, :network_type) SENSITIVE = [] include Aws::Structure end |