Class: Aws::Kafka::Types::ConsumerGroupReplication

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Details about consumer group replication.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumer_group_offset_sync_modeString

The consumer group offset synchronization mode. With LEGACY, offsets are synchronized when producers write to the source cluster. With ENHANCED, consumer offsets are synchronized regardless of producer location. ENHANCED requires a corresponding replicator that replicates data from the target cluster to the source cluster.

Returns:

  • (String)


1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-kafka/types.rb', line 1149

class ConsumerGroupReplication < Struct.new(
  :consumer_groups_to_exclude,
  :consumer_groups_to_replicate,
  :detect_and_copy_new_consumer_groups,
  :synchronise_consumer_group_offsets,
  :consumer_group_offset_sync_mode)
  SENSITIVE = []
  include Aws::Structure
end

#consumer_groups_to_excludeArray<String>

List of regular expression patterns indicating the consumer groups that should not be replicated.

Returns:

  • (Array<String>)


1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-kafka/types.rb', line 1149

class ConsumerGroupReplication < Struct.new(
  :consumer_groups_to_exclude,
  :consumer_groups_to_replicate,
  :detect_and_copy_new_consumer_groups,
  :synchronise_consumer_group_offsets,
  :consumer_group_offset_sync_mode)
  SENSITIVE = []
  include Aws::Structure
end

#consumer_groups_to_replicateArray<String>

List of regular expression patterns indicating the consumer groups to copy.

Returns:

  • (Array<String>)


1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-kafka/types.rb', line 1149

class ConsumerGroupReplication < Struct.new(
  :consumer_groups_to_exclude,
  :consumer_groups_to_replicate,
  :detect_and_copy_new_consumer_groups,
  :synchronise_consumer_group_offsets,
  :consumer_group_offset_sync_mode)
  SENSITIVE = []
  include Aws::Structure
end

#detect_and_copy_new_consumer_groupsBoolean

Enables synchronization of consumer groups to target cluster.

Returns:

  • (Boolean)


1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-kafka/types.rb', line 1149

class ConsumerGroupReplication < Struct.new(
  :consumer_groups_to_exclude,
  :consumer_groups_to_replicate,
  :detect_and_copy_new_consumer_groups,
  :synchronise_consumer_group_offsets,
  :consumer_group_offset_sync_mode)
  SENSITIVE = []
  include Aws::Structure
end

#synchronise_consumer_group_offsetsBoolean

Enables synchronization of consumer group offsets to target cluster. The translated offsets will be written to topic __consumer_offsets.

Returns:

  • (Boolean)


1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-kafka/types.rb', line 1149

class ConsumerGroupReplication < Struct.new(
  :consumer_groups_to_exclude,
  :consumer_groups_to_replicate,
  :detect_and_copy_new_consumer_groups,
  :synchronise_consumer_group_offsets,
  :consumer_group_offset_sync_mode)
  SENSITIVE = []
  include Aws::Structure
end