Class: Aws::Kafka::Types::CreateChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Creates a Channel that streams records from an Amazon MSK Express cluster topic to Amazon S3 or Apache Iceberg.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_nameString

The name of the channel. Must be unique within the cluster.

Returns:

  • (String)


397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/aws-sdk-kafka/types.rb', line 397

class CreateChannelRequest < Struct.new(
  :channel_name,
  :cluster_arn,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :logging_info,
  :s3_destination_configuration,
  :tags,
  :topic_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

The Amazon Resource Name (ARN) that uniquely identifies the cluster.

Returns:

  • (String)


397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/aws-sdk-kafka/types.rb', line 397

class CreateChannelRequest < Struct.new(
  :channel_name,
  :cluster_arn,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :logging_info,
  :s3_destination_configuration,
  :tags,
  :topic_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The encryption configuration applied to the channel.



397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/aws-sdk-kafka/types.rb', line 397

class CreateChannelRequest < Struct.new(
  :channel_name,
  :cluster_arn,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :logging_info,
  :s3_destination_configuration,
  :tags,
  :topic_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#iceberg_destination_configurationTypes::IcebergDestinationConfiguration

The Apache Iceberg destination for the channel. Mutually exclusive with s3DestinationConfiguration.



397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/aws-sdk-kafka/types.rb', line 397

class CreateChannelRequest < Struct.new(
  :channel_name,
  :cluster_arn,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :logging_info,
  :s3_destination_configuration,
  :tags,
  :topic_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#logging_infoTypes::ChannelLoggingInfo

The destinations to which the channel publishes operational logs.



397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/aws-sdk-kafka/types.rb', line 397

class CreateChannelRequest < Struct.new(
  :channel_name,
  :cluster_arn,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :logging_info,
  :s3_destination_configuration,
  :tags,
  :topic_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#s3_destination_configurationTypes::S3DestinationConfiguration

The Amazon S3 destination for the channel. Mutually exclusive with icebergDestinationConfiguration.



397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/aws-sdk-kafka/types.rb', line 397

class CreateChannelRequest < Struct.new(
  :channel_name,
  :cluster_arn,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :logging_info,
  :s3_destination_configuration,
  :tags,
  :topic_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags attached to the channel.

Returns:

  • (Hash<String,String>)


397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/aws-sdk-kafka/types.rb', line 397

class CreateChannelRequest < Struct.new(
  :channel_name,
  :cluster_arn,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :logging_info,
  :s3_destination_configuration,
  :tags,
  :topic_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end

#topic_configuration_listArray<Types::TopicConfiguration>

The list of topic configurations for the channel. Currently exactly one topic must be specified.

Returns:



397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/aws-sdk-kafka/types.rb', line 397

class CreateChannelRequest < Struct.new(
  :channel_name,
  :cluster_arn,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :logging_info,
  :s3_destination_configuration,
  :tags,
  :topic_configuration_list)
  SENSITIVE = []
  include Aws::Structure
end