Class: Aws::Kafka::Types::CreateConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Request body for CreateConfiguration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the configuration.

Returns:

  • (String)


1128
1129
1130
1131
1132
1133
1134
1135
# File 'lib/aws-sdk-kafka/types.rb', line 1128

class CreateConfigurationRequest < Struct.new(
  :description,
  :kafka_versions,
  :name,
  :server_properties)
  SENSITIVE = []
  include Aws::Structure
end

#kafka_versionsArray<String>

The versions of Apache Kafka with which you can use this MSK configuration.

Returns:

  • (Array<String>)


1128
1129
1130
1131
1132
1133
1134
1135
# File 'lib/aws-sdk-kafka/types.rb', line 1128

class CreateConfigurationRequest < Struct.new(
  :description,
  :kafka_versions,
  :name,
  :server_properties)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the configuration. Configuration names are strings that match the regex “^[0-9A-Za-z-]+$”.

Returns:

  • (String)


1128
1129
1130
1131
1132
1133
1134
1135
# File 'lib/aws-sdk-kafka/types.rb', line 1128

class CreateConfigurationRequest < Struct.new(
  :description,
  :kafka_versions,
  :name,
  :server_properties)
  SENSITIVE = []
  include Aws::Structure
end

#server_propertiesString

Returns:

  • (String)


1128
1129
1130
1131
1132
1133
1134
1135
# File 'lib/aws-sdk-kafka/types.rb', line 1128

class CreateConfigurationRequest < Struct.new(
  :description,
  :kafka_versions,
  :name,
  :server_properties)
  SENSITIVE = []
  include Aws::Structure
end