Class: Aws::Kafka::Types::DescribeChannelResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Contains the current configuration and state of a channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_arnString

The Amazon Resource Name (ARN) that uniquely identifies the channel.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_operation_arnString

The Amazon Resource Name (ARN) of the in-flight cluster operation. Returned only while the channel is in CREATING, UPDATING, or DELETING.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time when the channel was created.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#destination_typeString

The type of destination configured for the channel.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The encryption configuration applied to the channel.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#iceberg_destination_configurationTypes::IcebergDestinationConfiguration

The Apache Iceberg destination for the channel, if configured.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#logging_infoTypes::ChannelLoggingInfo

The destinations to which the channel publishes operational logs.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#s3_destination_configurationTypes::S3DestinationConfiguration

The Amazon S3 destination for the channel, if configured.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#state_infoTypes::ChannelStateInfo

Additional context for the current channel state, populated when the channel is in FAILED.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current lifecycle state of the channel.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags attached to the channel.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#topic_configuration_listArray<Types::TopicConfiguration>

The list of topic configurations for the channel.

Returns:



1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/aws-sdk-kafka/types.rb', line 1866

class DescribeChannelResponse < Struct.new(
  :channel_arn,
  :channel_name,
  :encryption_configuration,
  :iceberg_destination_configuration,
  :s3_destination_configuration,
  :status,
  :destination_type,
  :creation_time,
  :topic_configuration_list,
  :logging_info,
  :state_info,
  :cluster_operation_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end