Class: Aws::Kafka::Types::DescribeVpcConnectionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::DescribeVpcConnectionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Response body for DescribeVpcConnection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication ⇒ String
The authentication type of the VPC connection.
-
#creation_time ⇒ Time
The creation time of the VPC connection.
-
#security_groups ⇒ Array<String>
The list of security groups attached to the VPC connection.
-
#state ⇒ String
The state of the VPC connection.
-
#subnets ⇒ Array<String>
The list of subnets in the client VPC.
-
#tags ⇒ Hash<String,String>
Tags attached to the VPC connection.
-
#target_cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster.
-
#vpc_connection_arn ⇒ String
The Amazon Resource Name (ARN) of the VPC connection.
-
#vpc_id ⇒ String
The VPC ID of the VPC connection.
Instance Attribute Details
#authentication ⇒ String
The authentication type of the VPC connection.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/aws-sdk-kafka/types.rb', line 2307 class DescribeVpcConnectionResponse < Struct.new( :vpc_connection_arn, :target_cluster_arn, :state, :authentication, :vpc_id, :subnets, :security_groups, :creation_time, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The creation time of the VPC connection.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/aws-sdk-kafka/types.rb', line 2307 class DescribeVpcConnectionResponse < Struct.new( :vpc_connection_arn, :target_cluster_arn, :state, :authentication, :vpc_id, :subnets, :security_groups, :creation_time, :tags) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The list of security groups attached to the VPC connection.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/aws-sdk-kafka/types.rb', line 2307 class DescribeVpcConnectionResponse < Struct.new( :vpc_connection_arn, :target_cluster_arn, :state, :authentication, :vpc_id, :subnets, :security_groups, :creation_time, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the VPC connection. The possible states are AVAILABLE, INACTIVE, DEACTIVATING, DELETING, CREATING, REJECTING, REJECTED and FAILED.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/aws-sdk-kafka/types.rb', line 2307 class DescribeVpcConnectionResponse < Struct.new( :vpc_connection_arn, :target_cluster_arn, :state, :authentication, :vpc_id, :subnets, :security_groups, :creation_time, :tags) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<String>
The list of subnets in the client VPC.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/aws-sdk-kafka/types.rb', line 2307 class DescribeVpcConnectionResponse < Struct.new( :vpc_connection_arn, :target_cluster_arn, :state, :authentication, :vpc_id, :subnets, :security_groups, :creation_time, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags attached to the VPC connection.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/aws-sdk-kafka/types.rb', line 2307 class DescribeVpcConnectionResponse < Struct.new( :vpc_connection_arn, :target_cluster_arn, :state, :authentication, :vpc_id, :subnets, :security_groups, :creation_time, :tags) SENSITIVE = [] include Aws::Structure end |
#target_cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/aws-sdk-kafka/types.rb', line 2307 class DescribeVpcConnectionResponse < Struct.new( :vpc_connection_arn, :target_cluster_arn, :state, :authentication, :vpc_id, :subnets, :security_groups, :creation_time, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_connection_arn ⇒ String
The Amazon Resource Name (ARN) of the VPC connection.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/aws-sdk-kafka/types.rb', line 2307 class DescribeVpcConnectionResponse < Struct.new( :vpc_connection_arn, :target_cluster_arn, :state, :authentication, :vpc_id, :subnets, :security_groups, :creation_time, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The VPC ID of the VPC connection.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/aws-sdk-kafka/types.rb', line 2307 class DescribeVpcConnectionResponse < Struct.new( :vpc_connection_arn, :target_cluster_arn, :state, :authentication, :vpc_id, :subnets, :security_groups, :creation_time, :tags) SENSITIVE = [] include Aws::Structure end |