Class: Aws::Kafka::Types::EncryptionInTransit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

The settings for encrypting data in transit.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_brokerString

Indicates the encryption setting for data in transit between clients and brokers. You must set it to one of the following values.

TLS means that client-broker communication is enabled with TLS only.

TLS_PLAINTEXT means that client-broker communication is enabled for both TLS-encrypted, as well as plaintext data.

PLAINTEXT means that client-broker communication is enabled in plaintext only.

The default value is TLS.

Returns:

  • (String)


2436
2437
2438
2439
2440
2441
# File 'lib/aws-sdk-kafka/types.rb', line 2436

class EncryptionInTransit < Struct.new(
  :client_broker,
  :in_cluster)
  SENSITIVE = []
  include Aws::Structure
end

#in_clusterBoolean

When set to true, it indicates that data communication among the broker nodes of the cluster is encrypted. When set to false, the communication happens in plaintext.

The default value is true.

Returns:

  • (Boolean)


2436
2437
2438
2439
2440
2441
# File 'lib/aws-sdk-kafka/types.rb', line 2436

class EncryptionInTransit < Struct.new(
  :client_broker,
  :in_cluster)
  SENSITIVE = []
  include Aws::Structure
end