Class: Aws::Kafka::Types::ErrorInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ErrorInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Returns information about an error state of the cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
A number describing the error programmatically.
-
#error_string ⇒ String
An optional field to provide more details about the error.
Instance Attribute Details
#error_code ⇒ String
A number describing the error programmatically.
2541 2542 2543 2544 2545 2546 |
# File 'lib/aws-sdk-kafka/types.rb', line 2541 class ErrorInfo < Struct.new( :error_code, :error_string) SENSITIVE = [] include Aws::Structure end |
#error_string ⇒ String
An optional field to provide more details about the error.
2541 2542 2543 2544 2545 2546 |
# File 'lib/aws-sdk-kafka/types.rb', line 2541 class ErrorInfo < Struct.new( :error_code, :error_string) SENSITIVE = [] include Aws::Structure end |