Class: Aws::Kafka::Types::GetBootstrapBrokersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Returns a string containing one or more hostname:port pairs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bootstrap_broker_stringString

A string containing one or more hostname:port pairs.



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_ipv_6String

A string that contains one or more DNS names (or IP) and port pairs for IPv6 connectivity.



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_public_sasl_iamString

A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs. The following is an example.

{ "BootstrapBrokerStringSaslIam": "b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9198,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9198,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9198" }



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_public_sasl_scramString

A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs. The following is an example.

{ "BootstrapBrokerStringSaslScram": "b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9196,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9196,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9196" }



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_public_tlsString

A string containing one or more DNS names (or IP addresses) and TLS port pairs. The following is an example.

{ "BootstrapBrokerStringTls": "b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9194,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9194,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9194" }



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_sasl_iamString

A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs. The following is an example.

{ "BootstrapBrokerStringSaslIam": "b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9098,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9098,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9098" }



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_sasl_iam_ipv_6String

A string that contains one or more DNS names (or IP) and SASL IAM port pairs for IPv6 connectivity.



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_sasl_scramString

A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs. The following is an example.

{ "BootstrapBrokerStringSaslScram": "b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9096,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9096,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9096" }



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_sasl_scram_ipv_6String

A string that contains one or more DNS names (or IP) and SASL SCRAM port pairs for IPv6 connectivity.



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_tlsString

A string containing one or more DNS names (or IP addresses) and TLS port pairs. The following is an example.

{ "BootstrapBrokerStringTls": "b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9094,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9094,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9094" }



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_tls_ipv_6String

A string that contains one or more DNS names (or IP) and TLS port pairs for IPv6 connectivity.



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_vpc_connectivity_sasl_iamString

A string containing one or more dns name (or IP) and SASL IAM port pairs for VPC connectivity.



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_vpc_connectivity_sasl_scramString

A string containing one or more dns name (or IP) and SASL SCRAM port pairs for VPC connectivity.



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_broker_string_vpc_connectivity_tlsString

A string containing one or more dns name (or IP) and Tls port pairs for VPC connectivity.



2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-kafka/types.rb', line 2661

class GetBootstrapBrokersResponse < Struct.new(
  :bootstrap_broker_string,
  :bootstrap_broker_string_public_sasl_iam,
  :bootstrap_broker_string_public_sasl_scram,
  :bootstrap_broker_string_public_tls,
  :bootstrap_broker_string_tls,
  :bootstrap_broker_string_sasl_scram,
  :bootstrap_broker_string_sasl_iam,
  :bootstrap_broker_string_vpc_connectivity_tls,
  :bootstrap_broker_string_vpc_connectivity_sasl_scram,
  :bootstrap_broker_string_vpc_connectivity_sasl_iam,
  :bootstrap_broker_string_ipv_6,
  :bootstrap_broker_string_tls_ipv_6,
  :bootstrap_broker_string_sasl_scram_ipv_6,
  :bootstrap_broker_string_sasl_iam_ipv_6)
  SENSITIVE = []
  include Aws::Structure
end