Class: Aws::Kafka::Types::IcebergDestinationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Configuration of an Apache Iceberg destination for a channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#append_onlyBoolean

Whether the destination is append-only. Must be true; updates and deletes are not supported.

Returns:

  • (Boolean)


2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-kafka/types.rb', line 2731

class IcebergDestinationConfiguration < Struct.new(
  :append_only,
  :catalog,
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :destination_table_list,
  :schema_evolution,
  :service_execution_role_arn,
  :table_creation,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#catalogTypes::Catalog

The AWS Glue Data Catalog and S3 Tables warehouse used by the destination.

Returns:



2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-kafka/types.rb', line 2731

class IcebergDestinationConfiguration < Struct.new(
  :append_only,
  :catalog,
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :destination_table_list,
  :schema_evolution,
  :service_execution_role_arn,
  :table_creation,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#compression_typeString

The compression codec for Iceberg table data files. Defaults to ZSTD.

Returns:

  • (String)


2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-kafka/types.rb', line 2731

class IcebergDestinationConfiguration < Struct.new(
  :append_only,
  :catalog,
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :destination_table_list,
  :schema_evolution,
  :service_execution_role_arn,
  :table_creation,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#data_freshness_in_secondsInteger

The maximum time, in seconds, that records buffer in MSK before being flushed to the destination. Allowed range: 300 to 900. Default: 600.

Returns:

  • (Integer)


2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-kafka/types.rb', line 2731

class IcebergDestinationConfiguration < Struct.new(
  :append_only,
  :catalog,
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :destination_table_list,
  :schema_evolution,
  :service_execution_role_arn,
  :table_creation,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#dead_letter_queue_s3Types::DeadLetterQueueS3

The Amazon S3 bucket and prefix where MSK writes records that fail to deliver.



2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-kafka/types.rb', line 2731

class IcebergDestinationConfiguration < Struct.new(
  :append_only,
  :catalog,
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :destination_table_list,
  :schema_evolution,
  :service_execution_role_arn,
  :table_creation,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#destination_table_listArray<Types::DestinationTable>

The destination Iceberg tables. Currently exactly one table must be specified.

Returns:



2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-kafka/types.rb', line 2731

class IcebergDestinationConfiguration < Struct.new(
  :append_only,
  :catalog,
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :destination_table_list,
  :schema_evolution,
  :service_execution_role_arn,
  :table_creation,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#schema_evolutionTypes::SchemaEvolution

Configuration controlling whether the destination table's schema is evolved to match incoming records.



2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-kafka/types.rb', line 2731

class IcebergDestinationConfiguration < Struct.new(
  :append_only,
  :catalog,
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :destination_table_list,
  :schema_evolution,
  :service_execution_role_arn,
  :table_creation,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#service_execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role that MSK assumes to access the destination table, the AWS Glue Data Catalog, and the dead-letter Amazon S3 bucket.

Returns:

  • (String)


2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-kafka/types.rb', line 2731

class IcebergDestinationConfiguration < Struct.new(
  :append_only,
  :catalog,
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :destination_table_list,
  :schema_evolution,
  :service_execution_role_arn,
  :table_creation,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#table_creationTypes::TableCreation

Configuration controlling whether MSK creates the destination table if it does not already exist.



2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-kafka/types.rb', line 2731

class IcebergDestinationConfiguration < Struct.new(
  :append_only,
  :catalog,
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :destination_table_list,
  :schema_evolution,
  :service_execution_role_arn,
  :table_creation,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end