Class: Aws::Kafka::Types::IcebergDestinationUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::IcebergDestinationUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Update payload for an Apache Iceberg destination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_freshness_in_seconds ⇒ Integer
The maximum time, in seconds, that records buffer in MSK before being flushed to the destination.
Instance Attribute Details
#data_freshness_in_seconds ⇒ Integer
The maximum time, in seconds, that records buffer in MSK before being flushed to the destination. Allowed range: 300 to 900.
5569 5570 5571 5572 5573 |
# File 'lib/aws-sdk-kafka/types.rb', line 5569 class IcebergDestinationUpdate < Struct.new( :data_freshness_in_seconds) SENSITIVE = [] include Aws::Structure end |