Class: Aws::Kafka::Types::JmxExporter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Indicates whether you want to enable or disable the JMX Exporter.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabled_in_brokerBoolean

Indicates whether you want to enable or disable the JMX Exporter.

Returns:

  • (Boolean)


5656
5657
5658
5659
5660
# File 'lib/aws-sdk-kafka/types.rb', line 5656

class JmxExporter < Struct.new(
  :enabled_in_broker)
  SENSITIVE = []
  include Aws::Structure
end