Class: Aws::Kafka::Types::KafkaCluster

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Information about Kafka Cluster to be used as source / target for replication.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_msk_clusterTypes::AmazonMskCluster

Details of an Amazon MSK Cluster.



2433
2434
2435
2436
2437
2438
2439
2440
2441
# File 'lib/aws-sdk-kafka/types.rb', line 2433

class KafkaCluster < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end

#apache_kafka_clusterTypes::ApacheKafkaCluster

Details of an Apache Kafka Cluster.



2433
2434
2435
2436
2437
2438
2439
2440
2441
# File 'lib/aws-sdk-kafka/types.rb', line 2433

class KafkaCluster < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end

#client_authenticationTypes::KafkaClusterClientAuthentication

Details of the client authentication used by the Apache Kafka cluster.



2433
2434
2435
2436
2437
2438
2439
2440
2441
# File 'lib/aws-sdk-kafka/types.rb', line 2433

class KafkaCluster < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_in_transitTypes::KafkaClusterEncryptionInTransit

Details of encryption in transit to the Apache Kafka cluster.



2433
2434
2435
2436
2437
2438
2439
2440
2441
# File 'lib/aws-sdk-kafka/types.rb', line 2433

class KafkaCluster < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::KafkaClusterClientVpcConfig

Details of an Amazon VPC which has network connectivity to the Apache Kafka cluster.



2433
2434
2435
2436
2437
2438
2439
2440
2441
# File 'lib/aws-sdk-kafka/types.rb', line 2433

class KafkaCluster < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end