Class: Aws::Kafka::Types::KafkaClusterDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Information about Kafka Cluster used as source / target for replication.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_msk_clusterTypes::AmazonMskCluster

Details of an Amazon MSK Cluster.



2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/aws-sdk-kafka/types.rb', line 2544

class KafkaClusterDescription < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :kafka_cluster_alias,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end

#apache_kafka_clusterTypes::ApacheKafkaCluster

Details of an Apache Kafka Cluster.



2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/aws-sdk-kafka/types.rb', line 2544

class KafkaClusterDescription < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :kafka_cluster_alias,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end

#client_authenticationTypes::KafkaClusterClientAuthentication

Details of the client authentication used by the Apache Kafka cluster.



2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/aws-sdk-kafka/types.rb', line 2544

class KafkaClusterDescription < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :kafka_cluster_alias,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_in_transitTypes::KafkaClusterEncryptionInTransit

Details of encryption in transit to the Apache Kafka cluster.



2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/aws-sdk-kafka/types.rb', line 2544

class KafkaClusterDescription < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :kafka_cluster_alias,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end

#kafka_cluster_aliasString

The alias of the Kafka cluster. Used to prefix names of replicated topics.

Returns:

  • (String)


2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/aws-sdk-kafka/types.rb', line 2544

class KafkaClusterDescription < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :kafka_cluster_alias,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::KafkaClusterClientVpcConfig

Details of an Amazon VPC which has network connectivity to the Apache Kafka cluster.



2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/aws-sdk-kafka/types.rb', line 2544

class KafkaClusterDescription < Struct.new(
  :amazon_msk_cluster,
  :apache_kafka_cluster,
  :kafka_cluster_alias,
  :vpc_config,
  :client_authentication,
  :encryption_in_transit)
  SENSITIVE = []
  include Aws::Structure
end