Class: Aws::Kafka::Types::KafkaClusterEncryptionInTransit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Details of encryption in transit to the Apache Kafka cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_typeString

The type of encryption in transit to the Apache Kafka cluster.

Returns:

  • (String)


2524
2525
2526
2527
2528
2529
# File 'lib/aws-sdk-kafka/types.rb', line 2524

class KafkaClusterEncryptionInTransit < Struct.new(
  :encryption_type,
  :root_ca_certificate)
  SENSITIVE = []
  include Aws::Structure
end

#root_ca_certificateString

The root CA certificate.

Returns:

  • (String)


2524
2525
2526
2527
2528
2529
# File 'lib/aws-sdk-kafka/types.rb', line 2524

class KafkaClusterEncryptionInTransit < Struct.new(
  :encryption_type,
  :root_ca_certificate)
  SENSITIVE = []
  include Aws::Structure
end