Class: Aws::Kafka::Types::ListChannelsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_arnString

The Amazon Resource Name (ARN) that uniquely identifies the cluster.

Returns:

  • (String)


3906
3907
3908
3909
3910
3911
3912
3913
# File 'lib/aws-sdk-kafka/types.rb', line 3906

class ListChannelsRequest < Struct.new(
  :cluster_arn,
  :max_results,
  :next_token,
  :topic_name_filter)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Maximum number of channels to return in a single response.

Returns:

  • (Integer)


3906
3907
3908
3909
3910
3911
3912
3913
# File 'lib/aws-sdk-kafka/types.rb', line 3906

class ListChannelsRequest < Struct.new(
  :cluster_arn,
  :max_results,
  :next_token,
  :topic_name_filter)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response of ListChannels is truncated, it returns a nextToken in the response. This nextToken should be sent in the subsequent request to ListChannels.

Returns:

  • (String)


3906
3907
3908
3909
3910
3911
3912
3913
# File 'lib/aws-sdk-kafka/types.rb', line 3906

class ListChannelsRequest < Struct.new(
  :cluster_arn,
  :max_results,
  :next_token,
  :topic_name_filter)
  SENSITIVE = []
  include Aws::Structure
end

#topic_name_filterString

Filters results to channels whose topic name matches the specified value.

Returns:

  • (String)


3906
3907
3908
3909
3910
3911
3912
3913
# File 'lib/aws-sdk-kafka/types.rb', line 3906

class ListChannelsRequest < Struct.new(
  :cluster_arn,
  :max_results,
  :next_token,
  :topic_name_filter)
  SENSITIVE = []
  include Aws::Structure
end