Class: Aws::Kafka::Types::ListClientVpcConnectionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

The response contains an array of client VPC connections and a next token if the response is truncated.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_vpc_connectionsArray<Types::ClientVpcConnection>

List containing a ClientVpcConnection object.

Returns:



4278
4279
4280
4281
4282
4283
# File 'lib/aws-sdk-kafka/types.rb', line 4278

class ListClientVpcConnectionsResponse < Struct.new(
  :next_token,
  :client_vpc_connections)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response of ListClientVpcConnections is truncated, it returns a NextToken in the response. This Nexttoken should be sent in the subsequent request to ListClientVpcConnections.

Returns:



4278
4279
4280
4281
4282
4283
# File 'lib/aws-sdk-kafka/types.rb', line 4278

class ListClientVpcConnectionsResponse < Struct.new(
  :next_token,
  :client_vpc_connections)
  SENSITIVE = []
  include Aws::Structure
end