Class: Aws::Kafka::Types::ListClusterOperationsV2Response

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

The response contains an array containing cluster operation information and a next token if the response is truncated.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_operation_info_listArray<Types::ClusterOperationV2Summary>



3196
3197
3198
3199
3200
3201
# File 'lib/aws-sdk-kafka/types.rb', line 3196

class ListClusterOperationsV2Response < Struct.new(
  :cluster_operation_info_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Returns:

  • (String)


3196
3197
3198
3199
3200
3201
# File 'lib/aws-sdk-kafka/types.rb', line 3196

class ListClusterOperationsV2Response < Struct.new(
  :cluster_operation_info_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end