Class: Aws::Kafka::Types::LoggingInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

You can configure your MSK cluster to send broker logs to different destination types. This is a container for the configuration details related to broker logs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizer_logsTypes::AuthorizerLogs

You can configure your MSK cluster to send authorizer logs to different destination types.



4086
4087
4088
4089
4090
4091
# File 'lib/aws-sdk-kafka/types.rb', line 4086

class LoggingInfo < Struct.new(
  :authorizer_logs,
  :broker_logs)
  SENSITIVE = []
  include Aws::Structure
end

#broker_logsTypes::BrokerLogs

You can configure your MSK cluster to send broker logs to different destination types. This configuration specifies the details of these destinations.

Returns:



4086
4087
4088
4089
4090
4091
# File 'lib/aws-sdk-kafka/types.rb', line 4086

class LoggingInfo < Struct.new(
  :authorizer_logs,
  :broker_logs)
  SENSITIVE = []
  include Aws::Structure
end