Class: Aws::Kafka::Types::NodeExporter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Indicates whether you want to enable or disable the Node Exporter.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabled_in_brokerBoolean

Indicates whether you want to enable or disable the Node Exporter.

Returns:

  • (Boolean)


5684
5685
5686
5687
5688
# File 'lib/aws-sdk-kafka/types.rb', line 5684

class NodeExporter < Struct.new(
  :enabled_in_broker)
  SENSITIVE = []
  include Aws::Structure
end