Class: Aws::Kafka::Types::PartitionSpec
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::PartitionSpec
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Partition specification for an Apache Iceberg destination table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#partition_strategy ⇒ String
The partitioning strategy applied to records written to the table.
-
#source_list ⇒ Array<Types::PartitionSource>
The source columns used by the partitioning strategy.
Instance Attribute Details
#partition_strategy ⇒ String
The partitioning strategy applied to records written to the table.
6263 6264 6265 6266 6267 6268 |
# File 'lib/aws-sdk-kafka/types.rb', line 6263 class PartitionSpec < Struct.new( :partition_strategy, :source_list) SENSITIVE = [] include Aws::Structure end |
#source_list ⇒ Array<Types::PartitionSource>
The source columns used by the partitioning strategy. For TIME_HOUR, must contain exactly one source column whose value is a timestamp.
6263 6264 6265 6266 6267 6268 |
# File 'lib/aws-sdk-kafka/types.rb', line 6263 class PartitionSpec < Struct.new( :partition_strategy, :source_list) SENSITIVE = [] include Aws::Structure end |