Class: Aws::Kafka::Types::Provisioned
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::Provisioned
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Describes the provisioned cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#broker_node_group_info ⇒ Types::BrokerNodeGroupInfo
Information about the brokers.
-
#client_authentication ⇒ Types::ClientAuthentication
Includes all client authentication information.
-
#current_broker_software_info ⇒ Types::BrokerSoftwareInfo
Information about the version of software currently deployed on the Apache Kafka brokers in the cluster.
-
#customer_action_status ⇒ String
Determines if there is an action required from the customer.
-
#encryption_info ⇒ Types::EncryptionInfo
Includes all encryption-related information.
-
#enhanced_monitoring ⇒ String
Specifies which metrics are gathered for the MSK cluster.
-
#logging_info ⇒ Types::LoggingInfo
You can configure your MSK cluster to send broker logs to different destination types.
-
#number_of_broker_nodes ⇒ Integer
The number of brokers in the cluster.
-
#open_monitoring ⇒ Types::OpenMonitoringInfo
Settings for open monitoring using Prometheus.
-
#rebalancing ⇒ Types::Rebalancing
Specifies whether or not intelligent rebalancing is turned on for a newly created MSK Provisioned cluster with Express brokers.
-
#storage_mode ⇒ String
This controls storage mode for supported storage tiers.
-
#zookeeper_connect_string ⇒ String
The connection string to use to connect to the Apache ZooKeeper cluster.
-
#zookeeper_connect_string_tls ⇒ String
The connection string to use to connect to the Apache ZooKeeper cluster on a TLS port.
Instance Attribute Details
#broker_node_group_info ⇒ Types::BrokerNodeGroupInfo
Information about the brokers.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#client_authentication ⇒ Types::ClientAuthentication
Includes all client authentication information.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#current_broker_software_info ⇒ Types::BrokerSoftwareInfo
Information about the version of software currently deployed on the Apache Kafka brokers in the cluster.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#customer_action_status ⇒ String
Determines if there is an action required from the customer.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#encryption_info ⇒ Types::EncryptionInfo
Includes all encryption-related information.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#enhanced_monitoring ⇒ String
Specifies which metrics are gathered for the MSK cluster. This property has the following possible values: DEFAULT, PER_BROKER, PER_TOPIC_PER_BROKER, and PER_TOPIC_PER_PARTITION. For a list of the metrics associated with each of these levels of monitoring, see Monitoring.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#logging_info ⇒ Types::LoggingInfo
You can configure your MSK cluster to send broker logs to different destination types. This is a container for the configuration details related to broker logs.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#number_of_broker_nodes ⇒ Integer
The number of brokers in the cluster.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#open_monitoring ⇒ Types::OpenMonitoringInfo
Settings for open monitoring using Prometheus.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#rebalancing ⇒ Types::Rebalancing
Specifies whether or not intelligent rebalancing is turned on for a newly created MSK Provisioned cluster with Express brokers. Intelligent rebalancing performs automatic partition balancing operations when you scale your clusters up or down. By default, intelligent rebalancing is ACTIVE for all new Express-based clusters.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#storage_mode ⇒ String
This controls storage mode for supported storage tiers.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#zookeeper_connect_string ⇒ String
The connection string to use to connect to the Apache ZooKeeper cluster.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#zookeeper_connect_string_tls ⇒ String
The connection string to use to connect to the Apache ZooKeeper cluster on a TLS port.
3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/aws-sdk-kafka/types.rb', line 3634 class Provisioned < Struct.new( :broker_node_group_info, :current_broker_software_info, :client_authentication, :encryption_info, :enhanced_monitoring, :open_monitoring, :logging_info, :number_of_broker_nodes, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |