Class: Aws::Kafka::Types::ReplicationInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ReplicationInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Specifies configuration for replication between a source and target Kafka cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumer_group_replication ⇒ Types::ConsumerGroupReplication
Configuration relating to consumer group replication.
-
#source_kafka_cluster_arn ⇒ String
The ARN of the source Kafka cluster.
-
#source_kafka_cluster_id ⇒ String
The ID of the source Kafka cluster.
-
#target_compression_type ⇒ String
The compression type to use when producing records to target cluster.
-
#target_kafka_cluster_arn ⇒ String
The ARN of the target Kafka cluster.
-
#target_kafka_cluster_id ⇒ String
The ID of the target Kafka cluster.
-
#topic_replication ⇒ Types::TopicReplication
Configuration relating to topic replication.
Instance Attribute Details
#consumer_group_replication ⇒ Types::ConsumerGroupReplication
Configuration relating to consumer group replication.
3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 |
# File 'lib/aws-sdk-kafka/types.rb', line 3926 class ReplicationInfo < Struct.new( :consumer_group_replication, :source_kafka_cluster_arn, :source_kafka_cluster_id, :target_compression_type, :target_kafka_cluster_arn, :target_kafka_cluster_id, :topic_replication) SENSITIVE = [] include Aws::Structure end |
#source_kafka_cluster_arn ⇒ String
The ARN of the source Kafka cluster.
3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 |
# File 'lib/aws-sdk-kafka/types.rb', line 3926 class ReplicationInfo < Struct.new( :consumer_group_replication, :source_kafka_cluster_arn, :source_kafka_cluster_id, :target_compression_type, :target_kafka_cluster_arn, :target_kafka_cluster_id, :topic_replication) SENSITIVE = [] include Aws::Structure end |
#source_kafka_cluster_id ⇒ String
The ID of the source Kafka cluster.
3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 |
# File 'lib/aws-sdk-kafka/types.rb', line 3926 class ReplicationInfo < Struct.new( :consumer_group_replication, :source_kafka_cluster_arn, :source_kafka_cluster_id, :target_compression_type, :target_kafka_cluster_arn, :target_kafka_cluster_id, :topic_replication) SENSITIVE = [] include Aws::Structure end |
#target_compression_type ⇒ String
The compression type to use when producing records to target cluster.
3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 |
# File 'lib/aws-sdk-kafka/types.rb', line 3926 class ReplicationInfo < Struct.new( :consumer_group_replication, :source_kafka_cluster_arn, :source_kafka_cluster_id, :target_compression_type, :target_kafka_cluster_arn, :target_kafka_cluster_id, :topic_replication) SENSITIVE = [] include Aws::Structure end |
#target_kafka_cluster_arn ⇒ String
The ARN of the target Kafka cluster.
3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 |
# File 'lib/aws-sdk-kafka/types.rb', line 3926 class ReplicationInfo < Struct.new( :consumer_group_replication, :source_kafka_cluster_arn, :source_kafka_cluster_id, :target_compression_type, :target_kafka_cluster_arn, :target_kafka_cluster_id, :topic_replication) SENSITIVE = [] include Aws::Structure end |
#target_kafka_cluster_id ⇒ String
The ID of the target Kafka cluster.
3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 |
# File 'lib/aws-sdk-kafka/types.rb', line 3926 class ReplicationInfo < Struct.new( :consumer_group_replication, :source_kafka_cluster_arn, :source_kafka_cluster_id, :target_compression_type, :target_kafka_cluster_arn, :target_kafka_cluster_id, :topic_replication) SENSITIVE = [] include Aws::Structure end |
#topic_replication ⇒ Types::TopicReplication
Configuration relating to topic replication.
3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 |
# File 'lib/aws-sdk-kafka/types.rb', line 3926 class ReplicationInfo < Struct.new( :consumer_group_replication, :source_kafka_cluster_arn, :source_kafka_cluster_id, :target_compression_type, :target_kafka_cluster_arn, :target_kafka_cluster_id, :topic_replication) SENSITIVE = [] include Aws::Structure end |