Class: Aws::Kafka::Types::ReplicationTopicNameConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Configuration for specifying replicated topic names should be the same as their corresponding upstream topics or prefixed with source cluster alias.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The type of replicated topic name.

Returns:

  • (String)


4020
4021
4022
4023
4024
# File 'lib/aws-sdk-kafka/types.rb', line 4020

class ReplicationTopicNameConfiguration < Struct.new(
  :type)
  SENSITIVE = []
  include Aws::Structure
end