Class: Aws::Kafka::Types::ReplicatorCloudWatchLogs
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ReplicatorCloudWatchLogs
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Details of the CloudWatch Logs destination for replicator logs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Specifies whether broker logs get sent to the specified CloudWatch Logs destination for replication.
-
#log_group ⇒ String
The CloudWatch log group that is the destination for replicator logs.
Instance Attribute Details
#enabled ⇒ Boolean
Specifies whether broker logs get sent to the specified CloudWatch Logs destination for replication.
4059 4060 4061 4062 4063 4064 |
# File 'lib/aws-sdk-kafka/types.rb', line 4059 class ReplicatorCloudWatchLogs < Struct.new( :enabled, :log_group) SENSITIVE = [] include Aws::Structure end |
#log_group ⇒ String
The CloudWatch log group that is the destination for replicator logs.
4059 4060 4061 4062 4063 4064 |
# File 'lib/aws-sdk-kafka/types.rb', line 4059 class ReplicatorCloudWatchLogs < Struct.new( :enabled, :log_group) SENSITIVE = [] include Aws::Structure end |