Class: Aws::Kafka::Types::ReplicatorFirehose
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ReplicatorFirehose
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Details of the Kinesis Data Firehose delivery stream that is the destination for replicator logs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delivery_stream ⇒ String
The Kinesis Data Firehose delivery stream that is the destination for replicator logs.
-
#enabled ⇒ Boolean
Specifies whether broker logs get sent to the specified Kinesis Data Firehose delivery stream for replication.
Instance Attribute Details
#delivery_stream ⇒ String
The Kinesis Data Firehose delivery stream that is the destination for replicator logs.
4081 4082 4083 4084 4085 4086 |
# File 'lib/aws-sdk-kafka/types.rb', line 4081 class ReplicatorFirehose < Struct.new( :delivery_stream, :enabled) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Specifies whether broker logs get sent to the specified Kinesis Data Firehose delivery stream for replication.
4081 4082 4083 4084 4085 4086 |
# File 'lib/aws-sdk-kafka/types.rb', line 4081 class ReplicatorFirehose < Struct.new( :delivery_stream, :enabled) SENSITIVE = [] include Aws::Structure end |