Class: Aws::Kafka::Types::ReplicatorLogDelivery
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ReplicatorLogDelivery
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Details of the log delivery for the replicator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_logs ⇒ Types::ReplicatorCloudWatchLogs
Details of the CloudWatch Logs destination for replicator logs.
-
#firehose ⇒ Types::ReplicatorFirehose
Details of the Kinesis Data Firehose delivery stream that is the destination for replicator logs.
-
#s3 ⇒ Types::ReplicatorS3
Details of the Amazon S3 destination for replicator logs.
Instance Attribute Details
#cloud_watch_logs ⇒ Types::ReplicatorCloudWatchLogs
Details of the CloudWatch Logs destination for replicator logs.
4108 4109 4110 4111 4112 4113 4114 |
# File 'lib/aws-sdk-kafka/types.rb', line 4108 class ReplicatorLogDelivery < Struct.new( :cloud_watch_logs, :firehose, :s3) SENSITIVE = [] include Aws::Structure end |
#firehose ⇒ Types::ReplicatorFirehose
Details of the Kinesis Data Firehose delivery stream that is the destination for replicator logs.
4108 4109 4110 4111 4112 4113 4114 |
# File 'lib/aws-sdk-kafka/types.rb', line 4108 class ReplicatorLogDelivery < Struct.new( :cloud_watch_logs, :firehose, :s3) SENSITIVE = [] include Aws::Structure end |
#s3 ⇒ Types::ReplicatorS3
Details of the Amazon S3 destination for replicator logs.
4108 4109 4110 4111 4112 4113 4114 |
# File 'lib/aws-sdk-kafka/types.rb', line 4108 class ReplicatorLogDelivery < Struct.new( :cloud_watch_logs, :firehose, :s3) SENSITIVE = [] include Aws::Structure end |