Class: Aws::Kafka::Types::ReplicatorS3
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ReplicatorS3
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Details of the Amazon S3 destination for replicator logs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the S3 bucket that is the destination for replicator logs.
-
#enabled ⇒ Boolean
Specifies whether broker logs get sent to the specified Amazon S3 destination for replication.
-
#prefix ⇒ String
The S3 prefix that is the destination for replicator logs.
Instance Attribute Details
#bucket ⇒ String
The name of the S3 bucket that is the destination for replicator logs.
4069 4070 4071 4072 4073 4074 4075 |
# File 'lib/aws-sdk-kafka/types.rb', line 4069 class ReplicatorS3 < Struct.new( :bucket, :enabled, :prefix) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Specifies whether broker logs get sent to the specified Amazon S3 destination for replication.
4069 4070 4071 4072 4073 4074 4075 |
# File 'lib/aws-sdk-kafka/types.rb', line 4069 class ReplicatorS3 < Struct.new( :bucket, :enabled, :prefix) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
The S3 prefix that is the destination for replicator logs.
4069 4070 4071 4072 4073 4074 4075 |
# File 'lib/aws-sdk-kafka/types.rb', line 4069 class ReplicatorS3 < Struct.new( :bucket, :enabled, :prefix) SENSITIVE = [] include Aws::Structure end |