Class: Aws::Kafka::Types::ReplicatorSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ReplicatorSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Information about a replicator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time the replicator was created.
-
#current_version ⇒ String
The current version of the replicator.
-
#is_replicator_reference ⇒ Boolean
Whether this resource is a replicator reference.
-
#kafka_clusters_summary ⇒ Array<Types::KafkaClusterSummary>
Kafka Clusters used in setting up sources / targets for replication.
-
#replication_info_summary_list ⇒ Array<Types::ReplicationInfoSummary>
A list of summarized information of replications between clusters.
-
#replicator_arn ⇒ String
The Amazon Resource Name (ARN) of the replicator.
-
#replicator_name ⇒ String
The name of the replicator.
-
#replicator_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the replicator resource in the region where the replicator was created.
-
#replicator_state ⇒ String
State of the replicator.
Instance Attribute Details
#creation_time ⇒ Time
The time the replicator was created.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kafka/types.rb', line 4898 class ReplicatorSummary < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters_summary, :replication_info_summary_list, :replicator_arn, :replicator_name, :replicator_resource_arn, :replicator_state) SENSITIVE = [] include Aws::Structure end |
#current_version ⇒ String
The current version of the replicator.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kafka/types.rb', line 4898 class ReplicatorSummary < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters_summary, :replication_info_summary_list, :replicator_arn, :replicator_name, :replicator_resource_arn, :replicator_state) SENSITIVE = [] include Aws::Structure end |
#is_replicator_reference ⇒ Boolean
Whether this resource is a replicator reference.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kafka/types.rb', line 4898 class ReplicatorSummary < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters_summary, :replication_info_summary_list, :replicator_arn, :replicator_name, :replicator_resource_arn, :replicator_state) SENSITIVE = [] include Aws::Structure end |
#kafka_clusters_summary ⇒ Array<Types::KafkaClusterSummary>
Kafka Clusters used in setting up sources / targets for replication.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kafka/types.rb', line 4898 class ReplicatorSummary < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters_summary, :replication_info_summary_list, :replicator_arn, :replicator_name, :replicator_resource_arn, :replicator_state) SENSITIVE = [] include Aws::Structure end |
#replication_info_summary_list ⇒ Array<Types::ReplicationInfoSummary>
A list of summarized information of replications between clusters.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kafka/types.rb', line 4898 class ReplicatorSummary < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters_summary, :replication_info_summary_list, :replicator_arn, :replicator_name, :replicator_resource_arn, :replicator_state) SENSITIVE = [] include Aws::Structure end |
#replicator_arn ⇒ String
The Amazon Resource Name (ARN) of the replicator.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kafka/types.rb', line 4898 class ReplicatorSummary < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters_summary, :replication_info_summary_list, :replicator_arn, :replicator_name, :replicator_resource_arn, :replicator_state) SENSITIVE = [] include Aws::Structure end |
#replicator_name ⇒ String
The name of the replicator.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kafka/types.rb', line 4898 class ReplicatorSummary < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters_summary, :replication_info_summary_list, :replicator_arn, :replicator_name, :replicator_resource_arn, :replicator_state) SENSITIVE = [] include Aws::Structure end |
#replicator_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the replicator resource in the region where the replicator was created.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kafka/types.rb', line 4898 class ReplicatorSummary < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters_summary, :replication_info_summary_list, :replicator_arn, :replicator_name, :replicator_resource_arn, :replicator_state) SENSITIVE = [] include Aws::Structure end |
#replicator_state ⇒ String
State of the replicator.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-kafka/types.rb', line 4898 class ReplicatorSummary < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters_summary, :replication_info_summary_list, :replicator_arn, :replicator_name, :replicator_resource_arn, :replicator_state) SENSITIVE = [] include Aws::Structure end |