Class: Aws::Kafka::Types::S3DestinationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Configuration of an Amazon S3 destination for a channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_freshness_in_secondsInteger

The maximum time, in seconds, that records buffer in MSK before being flushed to the destination. Allowed range: 300 to 900. Default: 600.

Returns:

  • (Integer)


5582
5583
5584
5585
5586
5587
5588
5589
# File 'lib/aws-sdk-kafka/types.rb', line 5582

class S3DestinationConfiguration < Struct.new(
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :service_execution_role_arn,
  :storage)
  SENSITIVE = []
  include Aws::Structure
end

#dead_letter_queue_s3Types::DeadLetterQueueS3

The Amazon S3 bucket and prefix where MSK writes records that fail to deliver.



5582
5583
5584
5585
5586
5587
5588
5589
# File 'lib/aws-sdk-kafka/types.rb', line 5582

class S3DestinationConfiguration < Struct.new(
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :service_execution_role_arn,
  :storage)
  SENSITIVE = []
  include Aws::Structure
end

#service_execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role that MSK assumes to write to the destination Amazon S3 bucket and the dead-letter bucket.

Returns:

  • (String)


5582
5583
5584
5585
5586
5587
5588
5589
# File 'lib/aws-sdk-kafka/types.rb', line 5582

class S3DestinationConfiguration < Struct.new(
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :service_execution_role_arn,
  :storage)
  SENSITIVE = []
  include Aws::Structure
end

#storageTypes::S3Storage

The Amazon S3 bucket, prefix, and storage class for delivered records.

Returns:



5582
5583
5584
5585
5586
5587
5588
5589
# File 'lib/aws-sdk-kafka/types.rb', line 5582

class S3DestinationConfiguration < Struct.new(
  :data_freshness_in_seconds,
  :dead_letter_queue_s3,
  :service_execution_role_arn,
  :storage)
  SENSITIVE = []
  include Aws::Structure
end