Class: Aws::Kafka::Types::S3DestinationUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::S3DestinationUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Update payload for an Amazon S3 destination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_freshness_in_seconds ⇒ Integer
The maximum time, in seconds, that records buffer in MSK before being flushed to the destination.
Instance Attribute Details
#data_freshness_in_seconds ⇒ Integer
The maximum time, in seconds, that records buffer in MSK before being flushed to the destination. Allowed range: 300 to 900.
5584 5585 5586 5587 5588 |
# File 'lib/aws-sdk-kafka/types.rb', line 5584 class S3DestinationUpdate < Struct.new( :data_freshness_in_seconds) SENSITIVE = [] include Aws::Structure end |