Class: Aws::Kafka::Types::TopicConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Configuration of an Apache Kafka topic that feeds a channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#record_converterTypes::RecordConverter

Configuration that controls how Apache Kafka record values are deserialized for the destination.



5060
5061
5062
5063
5064
5065
5066
# File 'lib/aws-sdk-kafka/types.rb', line 5060

class TopicConfiguration < Struct.new(
  :record_converter,
  :record_schema,
  :topic_arn)
  SENSITIVE = []
  include Aws::Structure
end

#record_schemaTypes::RecordSchema

The schema used to validate records when the value converter requires one (for example, JSON_SCHEMA_GSR).

Returns:



5060
5061
5062
5063
5064
5065
5066
# File 'lib/aws-sdk-kafka/types.rb', line 5060

class TopicConfiguration < Struct.new(
  :record_converter,
  :record_schema,
  :topic_arn)
  SENSITIVE = []
  include Aws::Structure
end

#topic_arnString

The Amazon Resource Name (ARN) that uniquely identifies the topic.

Returns:

  • (String)


5060
5061
5062
5063
5064
5065
5066
# File 'lib/aws-sdk-kafka/types.rb', line 5060

class TopicConfiguration < Struct.new(
  :record_converter,
  :record_schema,
  :topic_arn)
  SENSITIVE = []
  include Aws::Structure
end