Class: Aws::Kafka::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Kafka::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kafka/client.rb
Overview
An API client for Kafka. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Kafka::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_associate_scram_secret(params = {}) ⇒ Types::BatchAssociateScramSecretResponse
Associates one or more Scram Secrets with an Amazon MSK cluster.
-
#batch_disassociate_scram_secret(params = {}) ⇒ Types::BatchDisassociateScramSecretResponse
Disassociates one or more Scram Secrets from an Amazon MSK cluster.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a new MSK cluster.
-
#create_cluster_v2(params = {}) ⇒ Types::CreateClusterV2Response
Creates a new Amazon MSK cluster of either the provisioned or the serverless type.
-
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new MSK configuration.
-
#create_replicator(params = {}) ⇒ Types::CreateReplicatorResponse
Creates a new Kafka Replicator.
-
#create_topic(params = {}) ⇒ Types::CreateTopicResponse
Creates a topic in the specified MSK cluster.
-
#create_vpc_connection(params = {}) ⇒ Types::CreateVpcConnectionResponse
Creates a new Amazon MSK VPC connection.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the request.
-
#delete_cluster_policy(params = {}) ⇒ Struct
Deletes the MSK cluster policy specified by the Amazon Resource Name (ARN) in your request.
-
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified MSK configuration.
-
#delete_replicator(params = {}) ⇒ Types::DeleteReplicatorResponse
Deletes a replicator.
-
#delete_topic(params = {}) ⇒ Types::DeleteTopicResponse
Deletes a topic in the specified MSK cluster.
-
#delete_vpc_connection(params = {}) ⇒ Types::DeleteVpcConnectionResponse
Deletes the Amazon MSK VPC connection specified in your request.
-
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.
-
#describe_cluster_operation(params = {}) ⇒ Types::DescribeClusterOperationResponse
Returns a description of the cluster operation specified by the ARN.
-
#describe_cluster_operation_v2(params = {}) ⇒ Types::DescribeClusterOperationV2Response
Returns a description of the cluster operation specified by the ARN.
-
#describe_cluster_v2(params = {}) ⇒ Types::DescribeClusterV2Response
Returns a description of the MSK cluster of either the provisioned or the serverless type whose Amazon Resource Name (ARN) is specified in the request.
-
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns a description of this MSK configuration.
-
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns a description of this revision of the configuration.
-
#describe_replicator(params = {}) ⇒ Types::DescribeReplicatorResponse
Returns a description of the Kafka Replicator whose Amazon Resource Name (ARN) is specified in the request.
-
#describe_topic(params = {}) ⇒ Types::DescribeTopicResponse
Returns topic details of this topic on a MSK cluster.
-
#describe_topic_partitions(params = {}) ⇒ Types::DescribeTopicPartitionsResponse
Returns partition details of this topic on a MSK cluster.
-
#describe_vpc_connection(params = {}) ⇒ Types::DescribeVpcConnectionResponse
Displays information about the specified Amazon MSK VPC connection.
-
#get_bootstrap_brokers(params = {}) ⇒ Types::GetBootstrapBrokersResponse
A list of brokers that a client application can use to bootstrap.
-
#get_cluster_policy(params = {}) ⇒ Types::GetClusterPolicyResponse
Retrieves the contents of the specified MSK cluster policy.
-
#get_compatible_kafka_versions(params = {}) ⇒ Types::GetCompatibleKafkaVersionsResponse
Gets the Apache Kafka versions to which you can update the MSK cluster.
-
#list_client_vpc_connections(params = {}) ⇒ Types::ListClientVpcConnectionsResponse
Displays a list of client VPC connections.
-
#list_cluster_operations(params = {}) ⇒ Types::ListClusterOperationsResponse
Returns a list of all the operations that have been performed on the specified MSK cluster.
-
#list_cluster_operations_v2(params = {}) ⇒ Types::ListClusterOperationsV2Response
Returns a list of all the operations that have been performed on the specified MSK cluster.
-
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns a list of all the MSK clusters in the current Region.
-
#list_clusters_v2(params = {}) ⇒ Types::ListClustersV2Response
Returns a list of all the MSK clusters in the current Region.
-
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all the revisions of an MSK configuration.
-
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all the MSK configurations in this Region.
-
#list_kafka_versions(params = {}) ⇒ Types::ListKafkaVersionsResponse
Returns a list of Apache Kafka versions.
-
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Returns a list of the broker nodes in the cluster.
-
#list_replicators(params = {}) ⇒ Types::ListReplicatorsResponse
Lists the replicators.
-
#list_scram_secrets(params = {}) ⇒ Types::ListScramSecretsResponse
Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags associated with the specified resource.
-
#list_topics(params = {}) ⇒ Types::ListTopicsResponse
List topics in a MSK cluster.
-
#list_vpc_connections(params = {}) ⇒ Types::ListVpcConnectionsResponse
Displays a list of Amazon MSK VPC connections.
-
#put_cluster_policy(params = {}) ⇒ Types::PutClusterPolicyResponse
Creates or updates the specified MSK cluster policy.
-
#reboot_broker(params = {}) ⇒ Types::RebootBrokerResponse
Executes a reboot on a broker.
-
#reject_client_vpc_connection(params = {}) ⇒ Struct
Returns an empty response.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified MSK resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tags associated with the keys that are provided in the query.
-
#update_broker_count(params = {}) ⇒ Types::UpdateBrokerCountResponse
Updates the number of broker nodes in the cluster.
-
#update_broker_storage(params = {}) ⇒ Types::UpdateBrokerStorageResponse
Updates the EBS storage associated with MSK brokers.
-
#update_broker_type(params = {}) ⇒ Types::UpdateBrokerTypeResponse
Updates all the brokers in the cluster to the specified type.
-
#update_cluster_configuration(params = {}) ⇒ Types::UpdateClusterConfigurationResponse
Updates the cluster with the configuration that is specified in the request body.
-
#update_cluster_kafka_version(params = {}) ⇒ Types::UpdateClusterKafkaVersionResponse
Updates the Apache Kafka version for the cluster.
-
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates an existing MSK configuration.
-
#update_connectivity(params = {}) ⇒ Types::UpdateConnectivityResponse
Updates the connectivity configuration for the MSK cluster.
-
#update_monitoring(params = {}) ⇒ Types::UpdateMonitoringResponse
Updates the monitoring settings for the cluster.
-
#update_rebalancing(params = {}) ⇒ Types::UpdateRebalancingResponse
Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.
-
#update_replication_info(params = {}) ⇒ Types::UpdateReplicationInfoResponse
Updates replication info of a replicator.
-
#update_security(params = {}) ⇒ Types::UpdateSecurityResponse
You can use this operation to update the encrypting and authentication settings for an existing cluster.
-
#update_storage(params = {}) ⇒ Types::UpdateStorageResponse
Updates cluster broker volume size (or) sets cluster storage mode to TIERED.
-
#update_topic(params = {}) ⇒ Types::UpdateTopicResponse
Updates the topic configuration or partition count in the specified MSK cluster.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-kafka/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3877 3878 3879 |
# File 'lib/aws-sdk-kafka/client.rb', line 3877 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3880 3881 3882 |
# File 'lib/aws-sdk-kafka/client.rb', line 3880 def errors_module Errors end |
Instance Method Details
#batch_associate_scram_secret(params = {}) ⇒ Types::BatchAssociateScramSecretResponse
Associates one or more Scram Secrets with an Amazon MSK cluster.
508 509 510 511 |
# File 'lib/aws-sdk-kafka/client.rb', line 508 def batch_associate_scram_secret(params = {}, = {}) req = build_request(:batch_associate_scram_secret, params) req.send_request() end |
#batch_disassociate_scram_secret(params = {}) ⇒ Types::BatchDisassociateScramSecretResponse
Disassociates one or more Scram Secrets from an Amazon MSK cluster.
2069 2070 2071 2072 |
# File 'lib/aws-sdk-kafka/client.rb', line 2069 def batch_disassociate_scram_secret(params = {}, = {}) req = build_request(:batch_disassociate_scram_secret, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 |
# File 'lib/aws-sdk-kafka/client.rb', line 3850 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Kafka') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kafka' context[:gem_version] = '1.115.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a new MSK cluster.
684 685 686 687 |
# File 'lib/aws-sdk-kafka/client.rb', line 684 def create_cluster(params = {}, = {}) req = build_request(:create_cluster, params) req.send_request() end |
#create_cluster_v2(params = {}) ⇒ Types::CreateClusterV2Response
Creates a new Amazon MSK cluster of either the provisioned or the serverless type.
849 850 851 852 |
# File 'lib/aws-sdk-kafka/client.rb', line 849 def create_cluster_v2(params = {}, = {}) req = build_request(:create_cluster_v2, params) req.send_request() end |
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new MSK configuration.
900 901 902 903 |
# File 'lib/aws-sdk-kafka/client.rb', line 900 def create_configuration(params = {}, = {}) req = build_request(:create_configuration, params) req.send_request() end |
#create_replicator(params = {}) ⇒ Types::CreateReplicatorResponse
Creates a new Kafka Replicator.
1032 1033 1034 1035 |
# File 'lib/aws-sdk-kafka/client.rb', line 1032 def create_replicator(params = {}, = {}) req = build_request(:create_replicator, params) req.send_request() end |
#create_topic(params = {}) ⇒ Types::CreateTopicResponse
Creates a topic in the specified MSK cluster.
1075 1076 1077 1078 |
# File 'lib/aws-sdk-kafka/client.rb', line 1075 def create_topic(params = {}, = {}) req = build_request(:create_topic, params) req.send_request() end |
#create_vpc_connection(params = {}) ⇒ Types::CreateVpcConnectionResponse
Creates a new Amazon MSK VPC connection.
1141 1142 1143 1144 |
# File 'lib/aws-sdk-kafka/client.rb', line 1141 def create_vpc_connection(params = {}, = {}) req = build_request(:create_vpc_connection, params) req.send_request() end |
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the request.
1174 1175 1176 1177 |
# File 'lib/aws-sdk-kafka/client.rb', line 1174 def delete_cluster(params = {}, = {}) req = build_request(:delete_cluster, params) req.send_request() end |
#delete_cluster_policy(params = {}) ⇒ Struct
Deletes the MSK cluster policy specified by the Amazon Resource Name (ARN) in your request.
3010 3011 3012 3013 |
# File 'lib/aws-sdk-kafka/client.rb', line 3010 def delete_cluster_policy(params = {}, = {}) req = build_request(:delete_cluster_policy, params) req.send_request() end |
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified MSK configuration. The configuration must be in the ACTIVE or DELETE_FAILED state.
1205 1206 1207 1208 |
# File 'lib/aws-sdk-kafka/client.rb', line 1205 def delete_configuration(params = {}, = {}) req = build_request(:delete_configuration, params) req.send_request() end |
#delete_replicator(params = {}) ⇒ Types::DeleteReplicatorResponse
Deletes a replicator.
1237 1238 1239 1240 |
# File 'lib/aws-sdk-kafka/client.rb', line 1237 def delete_replicator(params = {}, = {}) req = build_request(:delete_replicator, params) req.send_request() end |
#delete_topic(params = {}) ⇒ Types::DeleteTopicResponse
Deletes a topic in the specified MSK cluster.
1271 1272 1273 1274 |
# File 'lib/aws-sdk-kafka/client.rb', line 1271 def delete_topic(params = {}, = {}) req = build_request(:delete_topic, params) req.send_request() end |
#delete_vpc_connection(params = {}) ⇒ Types::DeleteVpcConnectionResponse
Deletes the Amazon MSK VPC connection specified in your request.
1300 1301 1302 1303 |
# File 'lib/aws-sdk-kafka/client.rb', line 1300 def delete_vpc_connection(params = {}, = {}) req = build_request(:delete_vpc_connection, params) req.send_request() end |
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.
1381 1382 1383 1384 |
# File 'lib/aws-sdk-kafka/client.rb', line 1381 def describe_cluster(params = {}, = {}) req = build_request(:describe_cluster, params) req.send_request() end |
#describe_cluster_operation(params = {}) ⇒ Types::DescribeClusterOperationResponse
Returns a description of the cluster operation specified by the ARN.
1597 1598 1599 1600 |
# File 'lib/aws-sdk-kafka/client.rb', line 1597 def describe_cluster_operation(params = {}, = {}) req = build_request(:describe_cluster_operation, params) req.send_request() end |
#describe_cluster_operation_v2(params = {}) ⇒ Types::DescribeClusterOperationV2Response
Returns a description of the cluster operation specified by the ARN.
1727 1728 1729 1730 |
# File 'lib/aws-sdk-kafka/client.rb', line 1727 def describe_cluster_operation_v2(params = {}, = {}) req = build_request(:describe_cluster_operation_v2, params) req.send_request() end |
#describe_cluster_v2(params = {}) ⇒ Types::DescribeClusterV2Response
Returns a description of the MSK cluster of either the provisioned or the serverless type whose Amazon Resource Name (ARN) is specified in the request.
1472 1473 1474 1475 |
# File 'lib/aws-sdk-kafka/client.rb', line 1472 def describe_cluster_v2(params = {}, = {}) req = build_request(:describe_cluster_v2, params) req.send_request() end |
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns a description of this MSK configuration.
1769 1770 1771 1772 |
# File 'lib/aws-sdk-kafka/client.rb', line 1769 def describe_configuration(params = {}, = {}) req = build_request(:describe_configuration, params) req.send_request() end |
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns a description of this revision of the configuration.
1807 1808 1809 1810 |
# File 'lib/aws-sdk-kafka/client.rb', line 1807 def describe_configuration_revision(params = {}, = {}) req = build_request(:describe_configuration_revision, params) req.send_request() end |
#describe_replicator(params = {}) ⇒ Types::DescribeReplicatorResponse
Returns a description of the Kafka Replicator whose Amazon Resource Name (ARN) is specified in the request.
1901 1902 1903 1904 |
# File 'lib/aws-sdk-kafka/client.rb', line 1901 def describe_replicator(params = {}, = {}) req = build_request(:describe_replicator, params) req.send_request() end |
#describe_topic(params = {}) ⇒ Types::DescribeTopicResponse
Returns topic details of this topic on a MSK cluster.
1941 1942 1943 1944 |
# File 'lib/aws-sdk-kafka/client.rb', line 1941 def describe_topic(params = {}, = {}) req = build_request(:describe_topic, params) req.send_request() end |
#describe_topic_partitions(params = {}) ⇒ Types::DescribeTopicPartitionsResponse
Returns partition details of this topic on a MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1987 1988 1989 1990 |
# File 'lib/aws-sdk-kafka/client.rb', line 1987 def describe_topic_partitions(params = {}, = {}) req = build_request(:describe_topic_partitions, params) req.send_request() end |
#describe_vpc_connection(params = {}) ⇒ Types::DescribeVpcConnectionResponse
Displays information about the specified Amazon MSK VPC connection.
2033 2034 2035 2036 |
# File 'lib/aws-sdk-kafka/client.rb', line 2033 def describe_vpc_connection(params = {}, = {}) req = build_request(:describe_vpc_connection, params) req.send_request() end |
#get_bootstrap_brokers(params = {}) ⇒ Types::GetBootstrapBrokersResponse
A list of brokers that a client application can use to bootstrap. This list doesn’t necessarily include all of the brokers in the cluster. The following Python 3.6 example shows how you can use the Amazon Resource Name (ARN) of a cluster to get its bootstrap brokers. If you don’t know the ARN of your cluster, you can use the ‘ListClusters` operation to get the ARNs of all the clusters in this account and Region.
2128 2129 2130 2131 |
# File 'lib/aws-sdk-kafka/client.rb', line 2128 def get_bootstrap_brokers(params = {}, = {}) req = build_request(:get_bootstrap_brokers, params) req.send_request() end |
#get_cluster_policy(params = {}) ⇒ Types::GetClusterPolicyResponse
Retrieves the contents of the specified MSK cluster policy.
3039 3040 3041 3042 |
# File 'lib/aws-sdk-kafka/client.rb', line 3039 def get_cluster_policy(params = {}, = {}) req = build_request(:get_cluster_policy, params) req.send_request() end |
#get_compatible_kafka_versions(params = {}) ⇒ Types::GetCompatibleKafkaVersionsResponse
Gets the Apache Kafka versions to which you can update the MSK cluster.
2159 2160 2161 2162 |
# File 'lib/aws-sdk-kafka/client.rb', line 2159 def get_compatible_kafka_versions(params = {}, = {}) req = build_request(:get_compatible_kafka_versions, params) req.send_request() end |
#list_client_vpc_connections(params = {}) ⇒ Types::ListClientVpcConnectionsResponse
Displays a list of client VPC connections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2881 2882 2883 2884 |
# File 'lib/aws-sdk-kafka/client.rb', line 2881 def list_client_vpc_connections(params = {}, = {}) req = build_request(:list_client_vpc_connections, params) req.send_request() end |
#list_cluster_operations(params = {}) ⇒ Types::ListClusterOperationsResponse
Returns a list of all the operations that have been performed on the specified MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2296 2297 2298 2299 |
# File 'lib/aws-sdk-kafka/client.rb', line 2296 def list_cluster_operations(params = {}, = {}) req = build_request(:list_cluster_operations, params) req.send_request() end |
#list_cluster_operations_v2(params = {}) ⇒ Types::ListClusterOperationsV2Response
Returns a list of all the operations that have been performed on the specified MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2341 2342 2343 2344 |
# File 'lib/aws-sdk-kafka/client.rb', line 2341 def list_cluster_operations_v2(params = {}, = {}) req = build_request(:list_cluster_operations_v2, params) req.send_request() end |
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns a list of all the MSK clusters in the current Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2432 2433 2434 2435 |
# File 'lib/aws-sdk-kafka/client.rb', line 2432 def list_clusters(params = {}, = {}) req = build_request(:list_clusters, params) req.send_request() end |
#list_clusters_v2(params = {}) ⇒ Types::ListClustersV2Response
Returns a list of all the MSK clusters in the current Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2542 2543 2544 2545 |
# File 'lib/aws-sdk-kafka/client.rb', line 2542 def list_clusters_v2(params = {}, = {}) req = build_request(:list_clusters_v2, params) req.send_request() end |
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all the revisions of an MSK configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2582 2583 2584 2585 |
# File 'lib/aws-sdk-kafka/client.rb', line 2582 def list_configuration_revisions(params = {}, = {}) req = build_request(:list_configuration_revisions, params) req.send_request() end |
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all the MSK configurations in this Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2626 2627 2628 2629 |
# File 'lib/aws-sdk-kafka/client.rb', line 2626 def list_configurations(params = {}, = {}) req = build_request(:list_configurations, params) req.send_request() end |
#list_kafka_versions(params = {}) ⇒ Types::ListKafkaVersionsResponse
Returns a list of Apache Kafka versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2662 2663 2664 2665 |
# File 'lib/aws-sdk-kafka/client.rb', line 2662 def list_kafka_versions(params = {}, = {}) req = build_request(:list_kafka_versions, params) req.send_request() end |
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Returns a list of the broker nodes in the cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2720 2721 2722 2723 |
# File 'lib/aws-sdk-kafka/client.rb', line 2720 def list_nodes(params = {}, = {}) req = build_request(:list_nodes, params) req.send_request() end |
#list_replicators(params = {}) ⇒ Types::ListReplicatorsResponse
Lists the replicators.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2772 2773 2774 2775 |
# File 'lib/aws-sdk-kafka/client.rb', line 2772 def list_replicators(params = {}, = {}) req = build_request(:list_replicators, params) req.send_request() end |
#list_scram_secrets(params = {}) ⇒ Types::ListScramSecretsResponse
Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2811 2812 2813 2814 |
# File 'lib/aws-sdk-kafka/client.rb', line 2811 def list_scram_secrets(params = {}, = {}) req = build_request(:list_scram_secrets, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags associated with the specified resource.
2839 2840 2841 2842 |
# File 'lib/aws-sdk-kafka/client.rb', line 2839 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_topics(params = {}) ⇒ Types::ListTopicsResponse
List topics in a MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2966 2967 2968 2969 |
# File 'lib/aws-sdk-kafka/client.rb', line 2966 def list_topics(params = {}, = {}) req = build_request(:list_topics, params) req.send_request() end |
#list_vpc_connections(params = {}) ⇒ Types::ListVpcConnectionsResponse
Displays a list of Amazon MSK VPC connections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2921 2922 2923 2924 |
# File 'lib/aws-sdk-kafka/client.rb', line 2921 def list_vpc_connections(params = {}, = {}) req = build_request(:list_vpc_connections, params) req.send_request() end |
#put_cluster_policy(params = {}) ⇒ Types::PutClusterPolicyResponse
Creates or updates the specified MSK cluster policy. If updating the policy, the currentVersion field is required in the request payload.
3073 3074 3075 3076 |
# File 'lib/aws-sdk-kafka/client.rb', line 3073 def put_cluster_policy(params = {}, = {}) req = build_request(:put_cluster_policy, params) req.send_request() end |
#reboot_broker(params = {}) ⇒ Types::RebootBrokerResponse
Executes a reboot on a broker.
3106 3107 3108 3109 |
# File 'lib/aws-sdk-kafka/client.rb', line 3106 def reboot_broker(params = {}, = {}) req = build_request(:reboot_broker, params) req.send_request() end |
#reject_client_vpc_connection(params = {}) ⇒ Struct
Returns an empty response.
2988 2989 2990 2991 |
# File 'lib/aws-sdk-kafka/client.rb', line 2988 def reject_client_vpc_connection(params = {}, = {}) req = build_request(:reject_client_vpc_connection, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified MSK resource.
3133 3134 3135 3136 |
# File 'lib/aws-sdk-kafka/client.rb', line 3133 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the tags associated with the keys that are provided in the query.
3158 3159 3160 3161 |
# File 'lib/aws-sdk-kafka/client.rb', line 3158 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_broker_count(params = {}) ⇒ Types::UpdateBrokerCountResponse
Updates the number of broker nodes in the cluster. You can use this operation to increase the number of brokers in an existing cluster. You can’t decrease the number of brokers.
3198 3199 3200 3201 |
# File 'lib/aws-sdk-kafka/client.rb', line 3198 def update_broker_count(params = {}, = {}) req = build_request(:update_broker_count, params) req.send_request() end |
#update_broker_storage(params = {}) ⇒ Types::UpdateBrokerStorageResponse
Updates the EBS storage associated with MSK brokers.
3290 3291 3292 3293 |
# File 'lib/aws-sdk-kafka/client.rb', line 3290 def update_broker_storage(params = {}, = {}) req = build_request(:update_broker_storage, params) req.send_request() end |
#update_broker_type(params = {}) ⇒ Types::UpdateBrokerTypeResponse
Updates all the brokers in the cluster to the specified type.
3236 3237 3238 3239 |
# File 'lib/aws-sdk-kafka/client.rb', line 3236 def update_broker_type(params = {}, = {}) req = build_request(:update_broker_type, params) req.send_request() end |
#update_cluster_configuration(params = {}) ⇒ Types::UpdateClusterConfigurationResponse
Updates the cluster with the configuration that is specified in the request body.
3371 3372 3373 3374 |
# File 'lib/aws-sdk-kafka/client.rb', line 3371 def update_cluster_configuration(params = {}, = {}) req = build_request(:update_cluster_configuration, params) req.send_request() end |
#update_cluster_kafka_version(params = {}) ⇒ Types::UpdateClusterKafkaVersionResponse
Updates the Apache Kafka version for the cluster.
3415 3416 3417 3418 |
# File 'lib/aws-sdk-kafka/client.rb', line 3415 def update_cluster_kafka_version(params = {}, = {}) req = build_request(:update_cluster_kafka_version, params) req.send_request() end |
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates an existing MSK configuration. The configuration must be in the Active state.
3330 3331 3332 3333 |
# File 'lib/aws-sdk-kafka/client.rb', line 3330 def update_configuration(params = {}, = {}) req = build_request(:update_configuration, params) req.send_request() end |
#update_connectivity(params = {}) ⇒ Types::UpdateConnectivityResponse
Updates the connectivity configuration for the MSK cluster.
3478 3479 3480 3481 |
# File 'lib/aws-sdk-kafka/client.rb', line 3478 def update_connectivity(params = {}, = {}) req = build_request(:update_connectivity, params) req.send_request() end |
#update_monitoring(params = {}) ⇒ Types::UpdateMonitoringResponse
Updates the monitoring settings for the cluster. You can use this operation to specify which Apache Kafka metrics you want Amazon MSK to send to Amazon CloudWatch. You can also specify settings for open monitoring with Prometheus.
3553 3554 3555 3556 |
# File 'lib/aws-sdk-kafka/client.rb', line 3553 def update_monitoring(params = {}, = {}) req = build_request(:update_monitoring, params) req.send_request() end |
#update_rebalancing(params = {}) ⇒ Types::UpdateRebalancingResponse
Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.
3594 3595 3596 3597 |
# File 'lib/aws-sdk-kafka/client.rb', line 3594 def update_rebalancing(params = {}, = {}) req = build_request(:update_rebalancing, params) req.send_request() end |
#update_replication_info(params = {}) ⇒ Types::UpdateReplicationInfoResponse
Updates replication info of a replicator.
3682 3683 3684 3685 |
# File 'lib/aws-sdk-kafka/client.rb', line 3682 def update_replication_info(params = {}, = {}) req = build_request(:update_replication_info, params) req.send_request() end |
#update_security(params = {}) ⇒ Types::UpdateSecurityResponse
You can use this operation to update the encrypting and authentication settings for an existing cluster.
3750 3751 3752 3753 |
# File 'lib/aws-sdk-kafka/client.rb', line 3750 def update_security(params = {}, = {}) req = build_request(:update_security, params) req.send_request() end |
#update_storage(params = {}) ⇒ Types::UpdateStorageResponse
Updates cluster broker volume size (or) sets cluster storage mode to TIERED.
3800 3801 3802 3803 |
# File 'lib/aws-sdk-kafka/client.rb', line 3800 def update_storage(params = {}, = {}) req = build_request(:update_storage, params) req.send_request() end |
#update_topic(params = {}) ⇒ Types::UpdateTopicResponse
Updates the topic configuration or partition count in the specified MSK cluster.
3841 3842 3843 3844 |
# File 'lib/aws-sdk-kafka/client.rb', line 3841 def update_topic(params = {}, = {}) req = build_request(:update_topic, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3870 3871 3872 |
# File 'lib/aws-sdk-kafka/client.rb', line 3870 def waiter_names [] end |