Class: Aws::Kafka::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Kafka::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kafka/client.rb
Overview
An API client for Kafka. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Kafka::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_associate_scram_secret(params = {}) ⇒ Types::BatchAssociateScramSecretResponse
Associates one or more Scram Secrets with an Amazon MSK cluster.
-
#batch_disassociate_scram_secret(params = {}) ⇒ Types::BatchDisassociateScramSecretResponse
Disassociates one or more Scram Secrets from an Amazon MSK cluster.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a new MSK cluster.
-
#create_cluster_v2(params = {}) ⇒ Types::CreateClusterV2Response
Creates a new Amazon MSK cluster of either the provisioned or the serverless type.
-
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new MSK configuration.
-
#create_replicator(params = {}) ⇒ Types::CreateReplicatorResponse
Creates a new Kafka Replicator.
-
#create_topic(params = {}) ⇒ Types::CreateTopicResponse
Creates a topic in the specified MSK cluster.
-
#create_vpc_connection(params = {}) ⇒ Types::CreateVpcConnectionResponse
Creates a new Amazon MSK VPC connection.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the request.
-
#delete_cluster_policy(params = {}) ⇒ Struct
Deletes the MSK cluster policy specified by the Amazon Resource Name (ARN) in your request.
-
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified MSK configuration.
-
#delete_replicator(params = {}) ⇒ Types::DeleteReplicatorResponse
Deletes a replicator.
-
#delete_topic(params = {}) ⇒ Types::DeleteTopicResponse
Deletes a topic in the specified MSK cluster.
-
#delete_vpc_connection(params = {}) ⇒ Types::DeleteVpcConnectionResponse
Deletes the Amazon MSK VPC connection specified in your request.
-
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.
-
#describe_cluster_operation(params = {}) ⇒ Types::DescribeClusterOperationResponse
Returns a description of the cluster operation specified by the ARN.
-
#describe_cluster_operation_v2(params = {}) ⇒ Types::DescribeClusterOperationV2Response
Returns a description of the cluster operation specified by the ARN.
-
#describe_cluster_v2(params = {}) ⇒ Types::DescribeClusterV2Response
Returns a description of the MSK cluster of either the provisioned or the serverless type whose Amazon Resource Name (ARN) is specified in the request.
-
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns a description of this MSK configuration.
-
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns a description of this revision of the configuration.
-
#describe_replicator(params = {}) ⇒ Types::DescribeReplicatorResponse
Returns a description of the Kafka Replicator whose Amazon Resource Name (ARN) is specified in the request.
-
#describe_topic(params = {}) ⇒ Types::DescribeTopicResponse
Returns topic details of this topic on a MSK cluster.
-
#describe_topic_partitions(params = {}) ⇒ Types::DescribeTopicPartitionsResponse
Returns partition details of this topic on a MSK cluster.
-
#describe_vpc_connection(params = {}) ⇒ Types::DescribeVpcConnectionResponse
Displays information about the specified Amazon MSK VPC connection.
-
#get_bootstrap_brokers(params = {}) ⇒ Types::GetBootstrapBrokersResponse
A list of brokers that a client application can use to bootstrap.
-
#get_cluster_policy(params = {}) ⇒ Types::GetClusterPolicyResponse
Retrieves the contents of the specified MSK cluster policy.
-
#get_compatible_kafka_versions(params = {}) ⇒ Types::GetCompatibleKafkaVersionsResponse
Gets the Apache Kafka versions to which you can update the MSK cluster.
-
#list_client_vpc_connections(params = {}) ⇒ Types::ListClientVpcConnectionsResponse
Displays a list of client VPC connections.
-
#list_cluster_operations(params = {}) ⇒ Types::ListClusterOperationsResponse
Returns a list of all the operations that have been performed on the specified MSK cluster.
-
#list_cluster_operations_v2(params = {}) ⇒ Types::ListClusterOperationsV2Response
Returns a list of all the operations that have been performed on the specified MSK cluster.
-
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns a list of all the MSK clusters in the current Region.
-
#list_clusters_v2(params = {}) ⇒ Types::ListClustersV2Response
Returns a list of all the MSK clusters in the current Region.
-
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all the revisions of an MSK configuration.
-
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all the MSK configurations in this Region.
-
#list_kafka_versions(params = {}) ⇒ Types::ListKafkaVersionsResponse
Returns a list of Apache Kafka versions.
-
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Returns a list of the broker nodes in the cluster.
-
#list_replicators(params = {}) ⇒ Types::ListReplicatorsResponse
Lists the replicators.
-
#list_scram_secrets(params = {}) ⇒ Types::ListScramSecretsResponse
Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags associated with the specified resource.
-
#list_topics(params = {}) ⇒ Types::ListTopicsResponse
List topics in a MSK cluster.
-
#list_vpc_connections(params = {}) ⇒ Types::ListVpcConnectionsResponse
Displays a list of Amazon MSK VPC connections.
-
#put_cluster_policy(params = {}) ⇒ Types::PutClusterPolicyResponse
Creates or updates the specified MSK cluster policy.
-
#reboot_broker(params = {}) ⇒ Types::RebootBrokerResponse
Executes a reboot on a broker.
-
#reject_client_vpc_connection(params = {}) ⇒ Struct
Returns an empty response.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified MSK resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tags associated with the keys that are provided in the query.
-
#update_broker_count(params = {}) ⇒ Types::UpdateBrokerCountResponse
Updates the number of broker nodes in the cluster.
-
#update_broker_storage(params = {}) ⇒ Types::UpdateBrokerStorageResponse
Updates the EBS storage associated with MSK brokers.
-
#update_broker_type(params = {}) ⇒ Types::UpdateBrokerTypeResponse
Updates all the brokers in the cluster to the specified type.
-
#update_cluster_configuration(params = {}) ⇒ Types::UpdateClusterConfigurationResponse
Updates the cluster with the configuration that is specified in the request body.
-
#update_cluster_kafka_version(params = {}) ⇒ Types::UpdateClusterKafkaVersionResponse
Updates the Apache Kafka version for the cluster.
-
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates an existing MSK configuration.
-
#update_connectivity(params = {}) ⇒ Types::UpdateConnectivityResponse
Updates the connectivity configuration for the MSK cluster.
-
#update_monitoring(params = {}) ⇒ Types::UpdateMonitoringResponse
Updates the monitoring settings for the cluster.
-
#update_rebalancing(params = {}) ⇒ Types::UpdateRebalancingResponse
Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.
-
#update_replication_info(params = {}) ⇒ Types::UpdateReplicationInfoResponse
Updates replication info of a replicator.
-
#update_security(params = {}) ⇒ Types::UpdateSecurityResponse
You can use this operation to update the encrypting and authentication settings for an existing cluster.
-
#update_storage(params = {}) ⇒ Types::UpdateStorageResponse
Updates cluster broker volume size (or) sets cluster storage mode to TIERED.
-
#update_topic(params = {}) ⇒ Types::UpdateTopicResponse
Updates the topic configuration or partition count in the specified MSK cluster.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-kafka/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3873 3874 3875 |
# File 'lib/aws-sdk-kafka/client.rb', line 3873 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3876 3877 3878 |
# File 'lib/aws-sdk-kafka/client.rb', line 3876 def errors_module Errors end |
Instance Method Details
#batch_associate_scram_secret(params = {}) ⇒ Types::BatchAssociateScramSecretResponse
Associates one or more Scram Secrets with an Amazon MSK cluster.
508 509 510 511 |
# File 'lib/aws-sdk-kafka/client.rb', line 508 def batch_associate_scram_secret(params = {}, = {}) req = build_request(:batch_associate_scram_secret, params) req.send_request() end |
#batch_disassociate_scram_secret(params = {}) ⇒ Types::BatchDisassociateScramSecretResponse
Disassociates one or more Scram Secrets from an Amazon MSK cluster.
2065 2066 2067 2068 |
# File 'lib/aws-sdk-kafka/client.rb', line 2065 def batch_disassociate_scram_secret(params = {}, = {}) req = build_request(:batch_disassociate_scram_secret, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 |
# File 'lib/aws-sdk-kafka/client.rb', line 3846 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Kafka') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kafka' context[:gem_version] = '1.113.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a new MSK cluster.
684 685 686 687 |
# File 'lib/aws-sdk-kafka/client.rb', line 684 def create_cluster(params = {}, = {}) req = build_request(:create_cluster, params) req.send_request() end |
#create_cluster_v2(params = {}) ⇒ Types::CreateClusterV2Response
Creates a new Amazon MSK cluster of either the provisioned or the serverless type.
849 850 851 852 |
# File 'lib/aws-sdk-kafka/client.rb', line 849 def create_cluster_v2(params = {}, = {}) req = build_request(:create_cluster_v2, params) req.send_request() end |
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new MSK configuration.
900 901 902 903 |
# File 'lib/aws-sdk-kafka/client.rb', line 900 def create_configuration(params = {}, = {}) req = build_request(:create_configuration, params) req.send_request() end |
#create_replicator(params = {}) ⇒ Types::CreateReplicatorResponse
Creates a new Kafka Replicator.
1029 1030 1031 1032 |
# File 'lib/aws-sdk-kafka/client.rb', line 1029 def create_replicator(params = {}, = {}) req = build_request(:create_replicator, params) req.send_request() end |
#create_topic(params = {}) ⇒ Types::CreateTopicResponse
Creates a topic in the specified MSK cluster.
1072 1073 1074 1075 |
# File 'lib/aws-sdk-kafka/client.rb', line 1072 def create_topic(params = {}, = {}) req = build_request(:create_topic, params) req.send_request() end |
#create_vpc_connection(params = {}) ⇒ Types::CreateVpcConnectionResponse
Creates a new Amazon MSK VPC connection.
1138 1139 1140 1141 |
# File 'lib/aws-sdk-kafka/client.rb', line 1138 def create_vpc_connection(params = {}, = {}) req = build_request(:create_vpc_connection, params) req.send_request() end |
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the request.
1171 1172 1173 1174 |
# File 'lib/aws-sdk-kafka/client.rb', line 1171 def delete_cluster(params = {}, = {}) req = build_request(:delete_cluster, params) req.send_request() end |
#delete_cluster_policy(params = {}) ⇒ Struct
Deletes the MSK cluster policy specified by the Amazon Resource Name (ARN) in your request.
3006 3007 3008 3009 |
# File 'lib/aws-sdk-kafka/client.rb', line 3006 def delete_cluster_policy(params = {}, = {}) req = build_request(:delete_cluster_policy, params) req.send_request() end |
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified MSK configuration. The configuration must be in the ACTIVE or DELETE_FAILED state.
1202 1203 1204 1205 |
# File 'lib/aws-sdk-kafka/client.rb', line 1202 def delete_configuration(params = {}, = {}) req = build_request(:delete_configuration, params) req.send_request() end |
#delete_replicator(params = {}) ⇒ Types::DeleteReplicatorResponse
Deletes a replicator.
1234 1235 1236 1237 |
# File 'lib/aws-sdk-kafka/client.rb', line 1234 def delete_replicator(params = {}, = {}) req = build_request(:delete_replicator, params) req.send_request() end |
#delete_topic(params = {}) ⇒ Types::DeleteTopicResponse
Deletes a topic in the specified MSK cluster.
1268 1269 1270 1271 |
# File 'lib/aws-sdk-kafka/client.rb', line 1268 def delete_topic(params = {}, = {}) req = build_request(:delete_topic, params) req.send_request() end |
#delete_vpc_connection(params = {}) ⇒ Types::DeleteVpcConnectionResponse
Deletes the Amazon MSK VPC connection specified in your request.
1297 1298 1299 1300 |
# File 'lib/aws-sdk-kafka/client.rb', line 1297 def delete_vpc_connection(params = {}, = {}) req = build_request(:delete_vpc_connection, params) req.send_request() end |
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.
1378 1379 1380 1381 |
# File 'lib/aws-sdk-kafka/client.rb', line 1378 def describe_cluster(params = {}, = {}) req = build_request(:describe_cluster, params) req.send_request() end |
#describe_cluster_operation(params = {}) ⇒ Types::DescribeClusterOperationResponse
Returns a description of the cluster operation specified by the ARN.
1594 1595 1596 1597 |
# File 'lib/aws-sdk-kafka/client.rb', line 1594 def describe_cluster_operation(params = {}, = {}) req = build_request(:describe_cluster_operation, params) req.send_request() end |
#describe_cluster_operation_v2(params = {}) ⇒ Types::DescribeClusterOperationV2Response
Returns a description of the cluster operation specified by the ARN.
1724 1725 1726 1727 |
# File 'lib/aws-sdk-kafka/client.rb', line 1724 def describe_cluster_operation_v2(params = {}, = {}) req = build_request(:describe_cluster_operation_v2, params) req.send_request() end |
#describe_cluster_v2(params = {}) ⇒ Types::DescribeClusterV2Response
Returns a description of the MSK cluster of either the provisioned or the serverless type whose Amazon Resource Name (ARN) is specified in the request.
1469 1470 1471 1472 |
# File 'lib/aws-sdk-kafka/client.rb', line 1469 def describe_cluster_v2(params = {}, = {}) req = build_request(:describe_cluster_v2, params) req.send_request() end |
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns a description of this MSK configuration.
1766 1767 1768 1769 |
# File 'lib/aws-sdk-kafka/client.rb', line 1766 def describe_configuration(params = {}, = {}) req = build_request(:describe_configuration, params) req.send_request() end |
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns a description of this revision of the configuration.
1804 1805 1806 1807 |
# File 'lib/aws-sdk-kafka/client.rb', line 1804 def describe_configuration_revision(params = {}, = {}) req = build_request(:describe_configuration_revision, params) req.send_request() end |
#describe_replicator(params = {}) ⇒ Types::DescribeReplicatorResponse
Returns a description of the Kafka Replicator whose Amazon Resource Name (ARN) is specified in the request.
1897 1898 1899 1900 |
# File 'lib/aws-sdk-kafka/client.rb', line 1897 def describe_replicator(params = {}, = {}) req = build_request(:describe_replicator, params) req.send_request() end |
#describe_topic(params = {}) ⇒ Types::DescribeTopicResponse
Returns topic details of this topic on a MSK cluster.
1937 1938 1939 1940 |
# File 'lib/aws-sdk-kafka/client.rb', line 1937 def describe_topic(params = {}, = {}) req = build_request(:describe_topic, params) req.send_request() end |
#describe_topic_partitions(params = {}) ⇒ Types::DescribeTopicPartitionsResponse
Returns partition details of this topic on a MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1983 1984 1985 1986 |
# File 'lib/aws-sdk-kafka/client.rb', line 1983 def describe_topic_partitions(params = {}, = {}) req = build_request(:describe_topic_partitions, params) req.send_request() end |
#describe_vpc_connection(params = {}) ⇒ Types::DescribeVpcConnectionResponse
Displays information about the specified Amazon MSK VPC connection.
2029 2030 2031 2032 |
# File 'lib/aws-sdk-kafka/client.rb', line 2029 def describe_vpc_connection(params = {}, = {}) req = build_request(:describe_vpc_connection, params) req.send_request() end |
#get_bootstrap_brokers(params = {}) ⇒ Types::GetBootstrapBrokersResponse
A list of brokers that a client application can use to bootstrap. This list doesn’t necessarily include all of the brokers in the cluster. The following Python 3.6 example shows how you can use the Amazon Resource Name (ARN) of a cluster to get its bootstrap brokers. If you don’t know the ARN of your cluster, you can use the ‘ListClusters` operation to get the ARNs of all the clusters in this account and Region.
2124 2125 2126 2127 |
# File 'lib/aws-sdk-kafka/client.rb', line 2124 def get_bootstrap_brokers(params = {}, = {}) req = build_request(:get_bootstrap_brokers, params) req.send_request() end |
#get_cluster_policy(params = {}) ⇒ Types::GetClusterPolicyResponse
Retrieves the contents of the specified MSK cluster policy.
3035 3036 3037 3038 |
# File 'lib/aws-sdk-kafka/client.rb', line 3035 def get_cluster_policy(params = {}, = {}) req = build_request(:get_cluster_policy, params) req.send_request() end |
#get_compatible_kafka_versions(params = {}) ⇒ Types::GetCompatibleKafkaVersionsResponse
Gets the Apache Kafka versions to which you can update the MSK cluster.
2155 2156 2157 2158 |
# File 'lib/aws-sdk-kafka/client.rb', line 2155 def get_compatible_kafka_versions(params = {}, = {}) req = build_request(:get_compatible_kafka_versions, params) req.send_request() end |
#list_client_vpc_connections(params = {}) ⇒ Types::ListClientVpcConnectionsResponse
Displays a list of client VPC connections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2877 2878 2879 2880 |
# File 'lib/aws-sdk-kafka/client.rb', line 2877 def list_client_vpc_connections(params = {}, = {}) req = build_request(:list_client_vpc_connections, params) req.send_request() end |
#list_cluster_operations(params = {}) ⇒ Types::ListClusterOperationsResponse
Returns a list of all the operations that have been performed on the specified MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2292 2293 2294 2295 |
# File 'lib/aws-sdk-kafka/client.rb', line 2292 def list_cluster_operations(params = {}, = {}) req = build_request(:list_cluster_operations, params) req.send_request() end |
#list_cluster_operations_v2(params = {}) ⇒ Types::ListClusterOperationsV2Response
Returns a list of all the operations that have been performed on the specified MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2337 2338 2339 2340 |
# File 'lib/aws-sdk-kafka/client.rb', line 2337 def list_cluster_operations_v2(params = {}, = {}) req = build_request(:list_cluster_operations_v2, params) req.send_request() end |
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns a list of all the MSK clusters in the current Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2428 2429 2430 2431 |
# File 'lib/aws-sdk-kafka/client.rb', line 2428 def list_clusters(params = {}, = {}) req = build_request(:list_clusters, params) req.send_request() end |
#list_clusters_v2(params = {}) ⇒ Types::ListClustersV2Response
Returns a list of all the MSK clusters in the current Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2538 2539 2540 2541 |
# File 'lib/aws-sdk-kafka/client.rb', line 2538 def list_clusters_v2(params = {}, = {}) req = build_request(:list_clusters_v2, params) req.send_request() end |
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all the revisions of an MSK configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2578 2579 2580 2581 |
# File 'lib/aws-sdk-kafka/client.rb', line 2578 def list_configuration_revisions(params = {}, = {}) req = build_request(:list_configuration_revisions, params) req.send_request() end |
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all the MSK configurations in this Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2622 2623 2624 2625 |
# File 'lib/aws-sdk-kafka/client.rb', line 2622 def list_configurations(params = {}, = {}) req = build_request(:list_configurations, params) req.send_request() end |
#list_kafka_versions(params = {}) ⇒ Types::ListKafkaVersionsResponse
Returns a list of Apache Kafka versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2658 2659 2660 2661 |
# File 'lib/aws-sdk-kafka/client.rb', line 2658 def list_kafka_versions(params = {}, = {}) req = build_request(:list_kafka_versions, params) req.send_request() end |
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Returns a list of the broker nodes in the cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2716 2717 2718 2719 |
# File 'lib/aws-sdk-kafka/client.rb', line 2716 def list_nodes(params = {}, = {}) req = build_request(:list_nodes, params) req.send_request() end |
#list_replicators(params = {}) ⇒ Types::ListReplicatorsResponse
Lists the replicators.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2768 2769 2770 2771 |
# File 'lib/aws-sdk-kafka/client.rb', line 2768 def list_replicators(params = {}, = {}) req = build_request(:list_replicators, params) req.send_request() end |
#list_scram_secrets(params = {}) ⇒ Types::ListScramSecretsResponse
Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2807 2808 2809 2810 |
# File 'lib/aws-sdk-kafka/client.rb', line 2807 def list_scram_secrets(params = {}, = {}) req = build_request(:list_scram_secrets, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags associated with the specified resource.
2835 2836 2837 2838 |
# File 'lib/aws-sdk-kafka/client.rb', line 2835 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_topics(params = {}) ⇒ Types::ListTopicsResponse
List topics in a MSK cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2962 2963 2964 2965 |
# File 'lib/aws-sdk-kafka/client.rb', line 2962 def list_topics(params = {}, = {}) req = build_request(:list_topics, params) req.send_request() end |
#list_vpc_connections(params = {}) ⇒ Types::ListVpcConnectionsResponse
Displays a list of Amazon MSK VPC connections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2917 2918 2919 2920 |
# File 'lib/aws-sdk-kafka/client.rb', line 2917 def list_vpc_connections(params = {}, = {}) req = build_request(:list_vpc_connections, params) req.send_request() end |
#put_cluster_policy(params = {}) ⇒ Types::PutClusterPolicyResponse
Creates or updates the specified MSK cluster policy. If updating the policy, the currentVersion field is required in the request payload.
3069 3070 3071 3072 |
# File 'lib/aws-sdk-kafka/client.rb', line 3069 def put_cluster_policy(params = {}, = {}) req = build_request(:put_cluster_policy, params) req.send_request() end |
#reboot_broker(params = {}) ⇒ Types::RebootBrokerResponse
Executes a reboot on a broker.
3102 3103 3104 3105 |
# File 'lib/aws-sdk-kafka/client.rb', line 3102 def reboot_broker(params = {}, = {}) req = build_request(:reboot_broker, params) req.send_request() end |
#reject_client_vpc_connection(params = {}) ⇒ Struct
Returns an empty response.
2984 2985 2986 2987 |
# File 'lib/aws-sdk-kafka/client.rb', line 2984 def reject_client_vpc_connection(params = {}, = {}) req = build_request(:reject_client_vpc_connection, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified MSK resource.
3129 3130 3131 3132 |
# File 'lib/aws-sdk-kafka/client.rb', line 3129 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the tags associated with the keys that are provided in the query.
3154 3155 3156 3157 |
# File 'lib/aws-sdk-kafka/client.rb', line 3154 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_broker_count(params = {}) ⇒ Types::UpdateBrokerCountResponse
Updates the number of broker nodes in the cluster. You can use this operation to increase the number of brokers in an existing cluster. You can’t decrease the number of brokers.
3194 3195 3196 3197 |
# File 'lib/aws-sdk-kafka/client.rb', line 3194 def update_broker_count(params = {}, = {}) req = build_request(:update_broker_count, params) req.send_request() end |
#update_broker_storage(params = {}) ⇒ Types::UpdateBrokerStorageResponse
Updates the EBS storage associated with MSK brokers.
3286 3287 3288 3289 |
# File 'lib/aws-sdk-kafka/client.rb', line 3286 def update_broker_storage(params = {}, = {}) req = build_request(:update_broker_storage, params) req.send_request() end |
#update_broker_type(params = {}) ⇒ Types::UpdateBrokerTypeResponse
Updates all the brokers in the cluster to the specified type.
3232 3233 3234 3235 |
# File 'lib/aws-sdk-kafka/client.rb', line 3232 def update_broker_type(params = {}, = {}) req = build_request(:update_broker_type, params) req.send_request() end |
#update_cluster_configuration(params = {}) ⇒ Types::UpdateClusterConfigurationResponse
Updates the cluster with the configuration that is specified in the request body.
3367 3368 3369 3370 |
# File 'lib/aws-sdk-kafka/client.rb', line 3367 def update_cluster_configuration(params = {}, = {}) req = build_request(:update_cluster_configuration, params) req.send_request() end |
#update_cluster_kafka_version(params = {}) ⇒ Types::UpdateClusterKafkaVersionResponse
Updates the Apache Kafka version for the cluster.
3411 3412 3413 3414 |
# File 'lib/aws-sdk-kafka/client.rb', line 3411 def update_cluster_kafka_version(params = {}, = {}) req = build_request(:update_cluster_kafka_version, params) req.send_request() end |
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates an existing MSK configuration. The configuration must be in the Active state.
3326 3327 3328 3329 |
# File 'lib/aws-sdk-kafka/client.rb', line 3326 def update_configuration(params = {}, = {}) req = build_request(:update_configuration, params) req.send_request() end |
#update_connectivity(params = {}) ⇒ Types::UpdateConnectivityResponse
Updates the connectivity configuration for the MSK cluster.
3474 3475 3476 3477 |
# File 'lib/aws-sdk-kafka/client.rb', line 3474 def update_connectivity(params = {}, = {}) req = build_request(:update_connectivity, params) req.send_request() end |
#update_monitoring(params = {}) ⇒ Types::UpdateMonitoringResponse
Updates the monitoring settings for the cluster. You can use this operation to specify which Apache Kafka metrics you want Amazon MSK to send to Amazon CloudWatch. You can also specify settings for open monitoring with Prometheus.
3549 3550 3551 3552 |
# File 'lib/aws-sdk-kafka/client.rb', line 3549 def update_monitoring(params = {}, = {}) req = build_request(:update_monitoring, params) req.send_request() end |
#update_rebalancing(params = {}) ⇒ Types::UpdateRebalancingResponse
Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.
3590 3591 3592 3593 |
# File 'lib/aws-sdk-kafka/client.rb', line 3590 def update_rebalancing(params = {}, = {}) req = build_request(:update_rebalancing, params) req.send_request() end |
#update_replication_info(params = {}) ⇒ Types::UpdateReplicationInfoResponse
Updates replication info of a replicator.
3678 3679 3680 3681 |
# File 'lib/aws-sdk-kafka/client.rb', line 3678 def update_replication_info(params = {}, = {}) req = build_request(:update_replication_info, params) req.send_request() end |
#update_security(params = {}) ⇒ Types::UpdateSecurityResponse
You can use this operation to update the encrypting and authentication settings for an existing cluster.
3746 3747 3748 3749 |
# File 'lib/aws-sdk-kafka/client.rb', line 3746 def update_security(params = {}, = {}) req = build_request(:update_security, params) req.send_request() end |
#update_storage(params = {}) ⇒ Types::UpdateStorageResponse
Updates cluster broker volume size (or) sets cluster storage mode to TIERED.
3796 3797 3798 3799 |
# File 'lib/aws-sdk-kafka/client.rb', line 3796 def update_storage(params = {}, = {}) req = build_request(:update_storage, params) req.send_request() end |
#update_topic(params = {}) ⇒ Types::UpdateTopicResponse
Updates the topic configuration or partition count in the specified MSK cluster.
3837 3838 3839 3840 |
# File 'lib/aws-sdk-kafka/client.rb', line 3837 def update_topic(params = {}, = {}) req = build_request(:update_topic, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3866 3867 3868 |
# File 'lib/aws-sdk-kafka/client.rb', line 3866 def waiter_names [] end |