Class: Aws::Kafka::Types::BrokerEBSVolumeInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Specifies the EBS volume upgrade information. The broker identifier must be set to the keyword ALL. This means the changes apply to all the brokers in the cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kafka_broker_node_idString

The ID of the broker to update.

Returns:

  • (String)


118
119
120
121
122
123
124
# File 'lib/aws-sdk-kafka/types.rb', line 118

class BrokerEBSVolumeInfo < Struct.new(
  :kafka_broker_node_id,
  :provisioned_throughput,
  :volume_size_gb)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_throughputTypes::ProvisionedThroughput

EBS volume provisioned throughput information.



118
119
120
121
122
123
124
# File 'lib/aws-sdk-kafka/types.rb', line 118

class BrokerEBSVolumeInfo < Struct.new(
  :kafka_broker_node_id,
  :provisioned_throughput,
  :volume_size_gb)
  SENSITIVE = []
  include Aws::Structure
end

#volume_size_gbInteger

Size of the EBS volume to update.

Returns:

  • (Integer)


118
119
120
121
122
123
124
# File 'lib/aws-sdk-kafka/types.rb', line 118

class BrokerEBSVolumeInfo < Struct.new(
  :kafka_broker_node_id,
  :provisioned_throughput,
  :volume_size_gb)
  SENSITIVE = []
  include Aws::Structure
end