Class: Aws::Kafka::Types::ClusterInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Returns information about a cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#active_operation_arnString

Arn of active cluster operation.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#broker_node_group_infoTypes::BrokerNodeGroupInfo

Information about the brokers.



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#client_authenticationTypes::ClientAuthentication

Includes all client authentication information.



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

The Amazon Resource Name (ARN) that uniquely identifies the cluster.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The name of the cluster.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time when the cluster was created.

Returns:

  • (Time)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#current_broker_software_infoTypes::BrokerSoftwareInfo

Information about the version of software currently deployed on the Apache Kafka brokers in the cluster.



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#current_versionString

The current version of the MSK cluster. Cluster versions aren't simple integers. You can obtain the current version by describing the cluster. An example version is KTVPDKIKX0DER.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#customer_action_statusString

Determines if there is an action required from the customer.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_infoTypes::EncryptionInfo

Includes all encryption-related information.



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_monitoringString

Specifies which metrics are gathered for the MSK cluster. This property has the following possible values: DEFAULT, PER_BROKER, PER_TOPIC_PER_BROKER, and PER_TOPIC_PER_PARTITION. For a list of the metrics associated with each of these levels of monitoring, see Monitoring.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#logging_infoTypes::LoggingInfo

You can configure your MSK cluster to send broker logs to different destination types. This is a container for the configuration details related to broker logs.

Returns:



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_broker_nodesInteger

The number of broker nodes in the cluster.

Returns:

  • (Integer)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#open_monitoringTypes::OpenMonitoring

Settings for open monitoring using Prometheus.



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#rebalancingTypes::Rebalancing

Contains information about intelligent rebalancing for new MSK Provisioned clusters with Express brokers. By default, intelligent rebalancing status is ACTIVE.

Returns:



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the cluster. The possible states are ACTIVE, CREATING, DELETING, FAILED, HEALING, MAINTENANCE, REBOOTING_BROKER, and UPDATING.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#state_infoTypes::StateInfo

Contains information about the state of the Amazon MSK cluster.

Returns:



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#storage_modeString

This controls storage mode for supported storage tiers.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Tags attached to the cluster.

Returns:

  • (Hash<String,String>)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#zookeeper_connect_stringString

The connection string to use to connect to the Apache ZooKeeper cluster.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end

#zookeeper_connect_string_tlsString

The connection string to use to connect to zookeeper cluster on Tls port.

Returns:

  • (String)


575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/aws-sdk-kafka/types.rb', line 575

class ClusterInfo < Struct.new(
  :active_operation_arn,
  :broker_node_group_info,
  :client_authentication,
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :current_broker_software_info,
  :logging_info,
  :current_version,
  :encryption_info,
  :enhanced_monitoring,
  :number_of_broker_nodes,
  :open_monitoring,
  :state,
  :state_info,
  :tags,
  :zookeeper_connect_string,
  :zookeeper_connect_string_tls,
  :storage_mode,
  :rebalancing,
  :customer_action_status)
  SENSITIVE = []
  include Aws::Structure
end