Class: Aws::Kafka::Types::ClusterInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ClusterInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Returns information about a cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_operation_arn ⇒ String
Arn of active cluster operation.
-
#broker_node_group_info ⇒ Types::BrokerNodeGroupInfo
Information about the brokers.
-
#client_authentication ⇒ Types::ClientAuthentication
Includes all client authentication information.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
-
#cluster_name ⇒ String
The name of the cluster.
-
#creation_time ⇒ Time
The time when the cluster was created.
-
#current_broker_software_info ⇒ Types::BrokerSoftwareInfo
Information about the version of software currently deployed on the Apache Kafka brokers in the cluster.
-
#current_version ⇒ String
The current version of the MSK cluster.
-
#customer_action_status ⇒ String
Determines if there is an action required from the customer.
-
#encryption_info ⇒ Types::EncryptionInfo
Includes all encryption-related information.
-
#enhanced_monitoring ⇒ String
Specifies which metrics are gathered for the MSK cluster.
-
#logging_info ⇒ Types::LoggingInfo
You can configure your MSK cluster to send broker logs to different destination types.
-
#number_of_broker_nodes ⇒ Integer
The number of broker nodes in the cluster.
-
#open_monitoring ⇒ Types::OpenMonitoring
Settings for open monitoring using Prometheus.
-
#rebalancing ⇒ Types::Rebalancing
Contains information about intelligent rebalancing for new MSK Provisioned clusters with Express brokers.
-
#state ⇒ String
The state of the cluster.
-
#state_info ⇒ Types::StateInfo
Contains information about the state of the Amazon MSK cluster.
-
#storage_mode ⇒ String
This controls storage mode for supported storage tiers.
-
#tags ⇒ Hash<String,String>
Tags attached to the cluster.
-
#zookeeper_connect_string ⇒ String
The connection string to use to connect to the Apache ZooKeeper cluster.
-
#zookeeper_connect_string_tls ⇒ String
The connection string to use to connect to zookeeper cluster on Tls port.
Instance Attribute Details
#active_operation_arn ⇒ String
Arn of active cluster operation.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#broker_node_group_info ⇒ Types::BrokerNodeGroupInfo
Information about the brokers.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#client_authentication ⇒ Types::ClientAuthentication
Includes all client authentication information.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of the cluster.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the cluster was created.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#current_broker_software_info ⇒ Types::BrokerSoftwareInfo
Information about the version of software currently deployed on the Apache Kafka brokers in the cluster.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#current_version ⇒ String
The current version of the MSK cluster. Cluster versions aren’t simple integers. You can obtain the current version by describing the cluster. An example version is KTVPDKIKX0DER.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#customer_action_status ⇒ String
Determines if there is an action required from the customer.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#encryption_info ⇒ Types::EncryptionInfo
Includes all encryption-related information.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#enhanced_monitoring ⇒ String
Specifies which metrics are gathered for the MSK cluster. This property has the following possible values: DEFAULT, PER_BROKER, PER_TOPIC_PER_BROKER, and PER_TOPIC_PER_PARTITION. For a list of the metrics associated with each of these levels of monitoring, see [Monitoring].
[1]: docs.aws.amazon.com/msk/latest/developerguide/monitoring.html
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#logging_info ⇒ Types::LoggingInfo
You can configure your MSK cluster to send broker logs to different destination types. This is a container for the configuration details related to broker logs.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#number_of_broker_nodes ⇒ Integer
The number of broker nodes in the cluster.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#open_monitoring ⇒ Types::OpenMonitoring
Settings for open monitoring using Prometheus.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#rebalancing ⇒ Types::Rebalancing
Contains information about intelligent rebalancing for new MSK Provisioned clusters with Express brokers. By default, intelligent rebalancing status is ACTIVE.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the cluster. The possible states are ACTIVE, CREATING, DELETING, FAILED, HEALING, MAINTENANCE, REBOOTING_BROKER, and UPDATING.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#state_info ⇒ Types::StateInfo
Contains information about the state of the Amazon MSK cluster.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#storage_mode ⇒ String
This controls storage mode for supported storage tiers.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags attached to the cluster.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#zookeeper_connect_string ⇒ String
The connection string to use to connect to the Apache ZooKeeper cluster.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |
#zookeeper_connect_string_tls ⇒ String
The connection string to use to connect to zookeeper cluster on Tls port.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-kafka/types.rb', line 438 class ClusterInfo < Struct.new( :active_operation_arn, :broker_node_group_info, :client_authentication, :cluster_arn, :cluster_name, :creation_time, :current_broker_software_info, :logging_info, :current_version, :encryption_info, :enhanced_monitoring, :number_of_broker_nodes, :open_monitoring, :state, :state_info, :tags, :zookeeper_connect_string, :zookeeper_connect_string_tls, :storage_mode, :rebalancing, :customer_action_status) SENSITIVE = [] include Aws::Structure end |