Class: Aws::Kafka::Types::Configuration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::Configuration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Represents an MSK Configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the configuration.
-
#creation_time ⇒ Time
The time when the configuration was created.
-
#description ⇒ String
The description of the configuration.
-
#kafka_versions ⇒ Array<String>
An array of the versions of Apache Kafka with which you can use this MSK configuration.
-
#latest_revision ⇒ Types::ConfigurationRevision
Latest revision of the configuration.
-
#name ⇒ String
The name of the configuration.
-
#state ⇒ String
The state of a configuration.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the configuration.
817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/aws-sdk-kafka/types.rb', line 817 class Configuration < Struct.new( :arn, :creation_time, :description, :kafka_versions, :latest_revision, :name, :state) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the configuration was created.
817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/aws-sdk-kafka/types.rb', line 817 class Configuration < Struct.new( :arn, :creation_time, :description, :kafka_versions, :latest_revision, :name, :state) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the configuration.
817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/aws-sdk-kafka/types.rb', line 817 class Configuration < Struct.new( :arn, :creation_time, :description, :kafka_versions, :latest_revision, :name, :state) SENSITIVE = [] include Aws::Structure end |
#kafka_versions ⇒ Array<String>
An array of the versions of Apache Kafka with which you can use this MSK configuration. You can use this configuration for an MSK cluster only if the Apache Kafka version specified for the cluster appears in this array.
817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/aws-sdk-kafka/types.rb', line 817 class Configuration < Struct.new( :arn, :creation_time, :description, :kafka_versions, :latest_revision, :name, :state) SENSITIVE = [] include Aws::Structure end |
#latest_revision ⇒ Types::ConfigurationRevision
Latest revision of the configuration.
817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/aws-sdk-kafka/types.rb', line 817 class Configuration < Struct.new( :arn, :creation_time, :description, :kafka_versions, :latest_revision, :name, :state) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configuration. Configuration names are strings that match the regex “^[0-9A-Za-z-]+$”.
817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/aws-sdk-kafka/types.rb', line 817 class Configuration < Struct.new( :arn, :creation_time, :description, :kafka_versions, :latest_revision, :name, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of a configuration.
817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/aws-sdk-kafka/types.rb', line 817 class Configuration < Struct.new( :arn, :creation_time, :description, :kafka_versions, :latest_revision, :name, :state) SENSITIVE = [] include Aws::Structure end |