Class: Aws::Kafka::Types::CreateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::CreateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Creates a Channel that streams records from an Amazon MSK Express cluster topic to Amazon S3 or Apache Iceberg.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_name ⇒ String
The name of the channel.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration applied to the channel.
-
#iceberg_destination_configuration ⇒ Types::IcebergDestinationConfiguration
The Apache Iceberg destination for the channel.
-
#logging_info ⇒ Types::ChannelLoggingInfo
The destinations to which the channel publishes operational logs.
-
#s3_destination_configuration ⇒ Types::S3DestinationConfiguration
The Amazon S3 destination for the channel.
-
#tags ⇒ Hash<String,String>
The tags attached to the channel.
-
#topic_configuration_list ⇒ Array<Types::TopicConfiguration>
The list of topic configurations for the channel.
Instance Attribute Details
#channel_name ⇒ String
The name of the channel. Must be unique within the cluster.
397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/aws-sdk-kafka/types.rb', line 397 class CreateChannelRequest < Struct.new( :channel_name, :cluster_arn, :encryption_configuration, :iceberg_destination_configuration, :logging_info, :s3_destination_configuration, :tags, :topic_configuration_list) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/aws-sdk-kafka/types.rb', line 397 class CreateChannelRequest < Struct.new( :channel_name, :cluster_arn, :encryption_configuration, :iceberg_destination_configuration, :logging_info, :s3_destination_configuration, :tags, :topic_configuration_list) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration applied to the channel.
397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/aws-sdk-kafka/types.rb', line 397 class CreateChannelRequest < Struct.new( :channel_name, :cluster_arn, :encryption_configuration, :iceberg_destination_configuration, :logging_info, :s3_destination_configuration, :tags, :topic_configuration_list) SENSITIVE = [] include Aws::Structure end |
#iceberg_destination_configuration ⇒ Types::IcebergDestinationConfiguration
The Apache Iceberg destination for the channel. Mutually exclusive with s3DestinationConfiguration.
397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/aws-sdk-kafka/types.rb', line 397 class CreateChannelRequest < Struct.new( :channel_name, :cluster_arn, :encryption_configuration, :iceberg_destination_configuration, :logging_info, :s3_destination_configuration, :tags, :topic_configuration_list) SENSITIVE = [] include Aws::Structure end |
#logging_info ⇒ Types::ChannelLoggingInfo
The destinations to which the channel publishes operational logs.
397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/aws-sdk-kafka/types.rb', line 397 class CreateChannelRequest < Struct.new( :channel_name, :cluster_arn, :encryption_configuration, :iceberg_destination_configuration, :logging_info, :s3_destination_configuration, :tags, :topic_configuration_list) SENSITIVE = [] include Aws::Structure end |
#s3_destination_configuration ⇒ Types::S3DestinationConfiguration
The Amazon S3 destination for the channel. Mutually exclusive with icebergDestinationConfiguration.
397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/aws-sdk-kafka/types.rb', line 397 class CreateChannelRequest < Struct.new( :channel_name, :cluster_arn, :encryption_configuration, :iceberg_destination_configuration, :logging_info, :s3_destination_configuration, :tags, :topic_configuration_list) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags attached to the channel.
397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/aws-sdk-kafka/types.rb', line 397 class CreateChannelRequest < Struct.new( :channel_name, :cluster_arn, :encryption_configuration, :iceberg_destination_configuration, :logging_info, :s3_destination_configuration, :tags, :topic_configuration_list) SENSITIVE = [] include Aws::Structure end |
#topic_configuration_list ⇒ Array<Types::TopicConfiguration>
The list of topic configurations for the channel. Currently exactly one topic must be specified.
397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/aws-sdk-kafka/types.rb', line 397 class CreateChannelRequest < Struct.new( :channel_name, :cluster_arn, :encryption_configuration, :iceberg_destination_configuration, :logging_info, :s3_destination_configuration, :tags, :topic_configuration_list) SENSITIVE = [] include Aws::Structure end |