Class: Aws::Kafka::Types::CreateClusterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::CreateClusterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Creates a cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#broker_node_group_info ⇒ Types::BrokerNodeGroupInfo
Information about the brokers.
-
#client_authentication ⇒ Types::ClientAuthentication
Includes all client authentication related information.
-
#cluster_name ⇒ String
The name of the cluster.
-
#configuration_info ⇒ Types::ConfigurationInfo
Represents the configuration that you want MSK to use for the cluster.
-
#encryption_info ⇒ Types::EncryptionInfo
Includes all encryption-related information.
-
#enhanced_monitoring ⇒ String
Specifies the level of monitoring for the MSK cluster.
-
#kafka_version ⇒ String
The version of Apache Kafka.
-
#logging_info ⇒ Types::LoggingInfo
LoggingInfo details.
-
#number_of_broker_nodes ⇒ Integer
The number of Apache Kafka broker nodes in the Amazon MSK cluster.
-
#open_monitoring ⇒ Types::OpenMonitoringInfo
The settings for open monitoring.
-
#rebalancing ⇒ Types::Rebalancing
Specifies if intelligent rebalancing should be turned on for the new MSK Provisioned cluster with Express brokers.
-
#storage_mode ⇒ String
This controls storage mode for supported storage tiers.
-
#tags ⇒ Hash<String,String>
Create tags when creating the cluster.
Instance Attribute Details
#broker_node_group_info ⇒ Types::BrokerNodeGroupInfo
Information about the brokers.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#client_authentication ⇒ Types::ClientAuthentication
Includes all client authentication related information.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of the cluster.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#configuration_info ⇒ Types::ConfigurationInfo
Represents the configuration that you want MSK to use for the cluster.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#encryption_info ⇒ Types::EncryptionInfo
Includes all encryption-related information.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#enhanced_monitoring ⇒ String
Specifies the level of monitoring for the MSK cluster. The possible values are DEFAULT, PER_BROKER, PER_TOPIC_PER_BROKER, and PER_TOPIC_PER_PARTITION.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#kafka_version ⇒ String
The version of Apache Kafka.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#logging_info ⇒ Types::LoggingInfo
LoggingInfo details.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#number_of_broker_nodes ⇒ Integer
The number of Apache Kafka broker nodes in the Amazon MSK cluster.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#open_monitoring ⇒ Types::OpenMonitoringInfo
The settings for open monitoring.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#rebalancing ⇒ Types::Rebalancing
Specifies if intelligent rebalancing should be turned on for the new MSK Provisioned cluster with Express brokers. By default, intelligent rebalancing status is ACTIVE for all new clusters.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#storage_mode ⇒ String
This controls storage mode for supported storage tiers.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Create tags when creating the cluster.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-kafka/types.rb', line 1091 class CreateClusterRequest < Struct.new( :broker_node_group_info, :client_authentication, :cluster_name, :configuration_info, :encryption_info, :enhanced_monitoring, :kafka_version, :logging_info, :number_of_broker_nodes, :open_monitoring, :tags, :rebalancing, :storage_mode) SENSITIVE = [] include Aws::Structure end |