Class: Aws::Kafka::Types::CreateReplicatorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::CreateReplicatorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Request body for replicator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A summary description of the replicator.
-
#kafka_clusters ⇒ Array<Types::KafkaCluster>
Kafka Clusters to use in setting up sources / targets for replication.
-
#log_delivery ⇒ Types::LogDelivery
Configuration for delivering replicator logs to customer destinations.
-
#replication_info_list ⇒ Array<Types::ReplicationInfo>
A list of replication configurations, where each configuration targets a given source cluster to target cluster replication flow.
-
#replicator_name ⇒ String
The name of the replicator.
-
#service_execution_role_arn ⇒ String
The ARN of the IAM role used by the replicator to access resources in the customer's account (e.g source and target clusters).
-
#tags ⇒ Hash<String,String>
List of tags to attach to created Replicator.
Instance Attribute Details
#description ⇒ String
A summary description of the replicator.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/aws-sdk-kafka/types.rb', line 1420 class CreateReplicatorRequest < Struct.new( :description, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_name, :service_execution_role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#kafka_clusters ⇒ Array<Types::KafkaCluster>
Kafka Clusters to use in setting up sources / targets for replication.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/aws-sdk-kafka/types.rb', line 1420 class CreateReplicatorRequest < Struct.new( :description, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_name, :service_execution_role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#log_delivery ⇒ Types::LogDelivery
Configuration for delivering replicator logs to customer destinations.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/aws-sdk-kafka/types.rb', line 1420 class CreateReplicatorRequest < Struct.new( :description, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_name, :service_execution_role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#replication_info_list ⇒ Array<Types::ReplicationInfo>
A list of replication configurations, where each configuration targets a given source cluster to target cluster replication flow.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/aws-sdk-kafka/types.rb', line 1420 class CreateReplicatorRequest < Struct.new( :description, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_name, :service_execution_role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#replicator_name ⇒ String
The name of the replicator. Alpha-numeric characters with '-' are allowed.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/aws-sdk-kafka/types.rb', line 1420 class CreateReplicatorRequest < Struct.new( :description, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_name, :service_execution_role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#service_execution_role_arn ⇒ String
The ARN of the IAM role used by the replicator to access resources in the customer's account (e.g source and target clusters)
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/aws-sdk-kafka/types.rb', line 1420 class CreateReplicatorRequest < Struct.new( :description, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_name, :service_execution_role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
List of tags to attach to created Replicator.
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/aws-sdk-kafka/types.rb', line 1420 class CreateReplicatorRequest < Struct.new( :description, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_name, :service_execution_role_arn, :tags) SENSITIVE = [] include Aws::Structure end |