Class: Aws::Kafka::Types::DescribeChannelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::DescribeChannelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Contains the current configuration and state of a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the channel.
-
#channel_name ⇒ String
The name of the channel.
-
#cluster_operation_arn ⇒ String
The Amazon Resource Name (ARN) of the in-flight cluster operation.
-
#creation_time ⇒ Time
The time when the channel was created.
-
#destination_type ⇒ String
The type of destination configured for the channel.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration applied to the channel.
-
#iceberg_destination_configuration ⇒ Types::IcebergDestinationConfiguration
The Apache Iceberg destination for the channel, if configured.
-
#logging_info ⇒ Types::ChannelLoggingInfo
The destinations to which the channel publishes operational logs.
-
#s3_destination_configuration ⇒ Types::S3DestinationConfiguration
The Amazon S3 destination for the channel, if configured.
-
#state_info ⇒ Types::ChannelStateInfo
Additional context for the current channel state, populated when the channel is in FAILED.
-
#status ⇒ String
The current lifecycle state of the channel.
-
#tags ⇒ Hash<String,String>
The tags attached to the channel.
-
#topic_configuration_list ⇒ Array<Types::TopicConfiguration>
The list of topic configurations for the channel.
Instance Attribute Details
#channel_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the channel.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#cluster_operation_arn ⇒ String
The Amazon Resource Name (ARN) of the in-flight cluster operation. Returned only while the channel is in CREATING, UPDATING, or DELETING.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the channel was created.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#destination_type ⇒ String
The type of destination configured for the channel.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration applied to the channel.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#iceberg_destination_configuration ⇒ Types::IcebergDestinationConfiguration
The Apache Iceberg destination for the channel, if configured.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#logging_info ⇒ Types::ChannelLoggingInfo
The destinations to which the channel publishes operational logs.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#s3_destination_configuration ⇒ Types::S3DestinationConfiguration
The Amazon S3 destination for the channel, if configured.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#state_info ⇒ Types::ChannelStateInfo
Additional context for the current channel state, populated when the channel is in FAILED.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current lifecycle state of the channel.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags attached to the channel.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#topic_configuration_list ⇒ Array<Types::TopicConfiguration>
The list of topic configurations for the channel.
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-kafka/types.rb', line 1841 class DescribeChannelResponse < Struct.new( :channel_arn, :channel_name, :encryption_configuration, :iceberg_destination_configuration, :s3_destination_configuration, :status, :destination_type, :creation_time, :topic_configuration_list, :logging_info, :state_info, :cluster_operation_arn, :tags) SENSITIVE = [] include Aws::Structure end |