Class: Aws::Kafka::Types::DescribeReplicatorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::DescribeReplicatorResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Response body for DescribeReplicator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time when the replicator was created.
-
#current_version ⇒ String
The current version number of the replicator.
-
#is_replicator_reference ⇒ Boolean
Whether this resource is a replicator reference.
-
#kafka_clusters ⇒ Array<Types::KafkaClusterDescription>
Kafka Clusters used in setting up sources / targets for replication.
-
#log_delivery ⇒ Types::LogDelivery
Configuration for log delivery for the replicator.
-
#replication_info_list ⇒ Array<Types::ReplicationInfoDescription>
A list of replication configurations, where each configuration targets a given source cluster to target cluster replication flow.
-
#replicator_arn ⇒ String
The Amazon Resource Name (ARN) of the replicator.
-
#replicator_description ⇒ String
The description of the replicator.
-
#replicator_name ⇒ String
The name of the replicator.
-
#replicator_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the replicator resource in the region where the replicator was created.
-
#replicator_state ⇒ String
State of the replicator.
-
#service_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the replicator to access resources in the customer’s account (e.g source and target clusters).
-
#state_info ⇒ Types::ReplicationStateInfo
Details about the state of the replicator.
-
#tags ⇒ Hash<String,String>
List of tags attached to the Replicator.
Instance Attribute Details
#creation_time ⇒ Time
The time when the replicator was created.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#current_version ⇒ String
The current version number of the replicator.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#is_replicator_reference ⇒ Boolean
Whether this resource is a replicator reference.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#kafka_clusters ⇒ Array<Types::KafkaClusterDescription>
Kafka Clusters used in setting up sources / targets for replication.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#log_delivery ⇒ Types::LogDelivery
Configuration for log delivery for the replicator.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#replication_info_list ⇒ Array<Types::ReplicationInfoDescription>
A list of replication configurations, where each configuration targets a given source cluster to target cluster replication flow.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#replicator_arn ⇒ String
The Amazon Resource Name (ARN) of the replicator.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#replicator_description ⇒ String
The description of the replicator.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#replicator_name ⇒ String
The name of the replicator.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#replicator_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the replicator resource in the region where the replicator was created.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#replicator_state ⇒ String
State of the replicator.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#service_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the replicator to access resources in the customer’s account (e.g source and target clusters)
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#state_info ⇒ Types::ReplicationStateInfo
Details about the state of the replicator.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
List of tags attached to the Replicator.
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/aws-sdk-kafka/types.rb', line 1959 class DescribeReplicatorResponse < Struct.new( :creation_time, :current_version, :is_replicator_reference, :kafka_clusters, :log_delivery, :replication_info_list, :replicator_arn, :replicator_description, :replicator_name, :replicator_resource_arn, :replicator_state, :service_execution_role_arn, :state_info, :tags) SENSITIVE = [] include Aws::Structure end |