Class: Aws::Kafka::Types::Firehose

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Firehose details for logs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delivery_streamString

The Kinesis Data Firehose delivery stream that is the destination for broker logs.

Returns:

  • (String)


2497
2498
2499
2500
2501
2502
# File 'lib/aws-sdk-kafka/types.rb', line 2497

class Firehose < Struct.new(
  :delivery_stream,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Specifies whether broker logs get sent to the specified Kinesis Data Firehose delivery stream.

Returns:

  • (Boolean)


2497
2498
2499
2500
2501
2502
# File 'lib/aws-sdk-kafka/types.rb', line 2497

class Firehose < Struct.new(
  :delivery_stream,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end