Class: Aws::Kafka::Types::GetBootstrapBrokersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::GetBootstrapBrokersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Returns a string containing one or more hostname:port pairs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bootstrap_broker_string ⇒ String
A string containing one or more hostname:port pairs.
-
#bootstrap_broker_string_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and port pairs for IPv6 connectivity.
-
#bootstrap_broker_string_public_sasl_iam ⇒ String
A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs.
-
#bootstrap_broker_string_public_sasl_scram ⇒ String
A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs.
-
#bootstrap_broker_string_public_tls ⇒ String
A string containing one or more DNS names (or IP addresses) and TLS port pairs.
-
#bootstrap_broker_string_sasl_iam ⇒ String
A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs.
-
#bootstrap_broker_string_sasl_iam_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and SASL IAM port pairs for IPv6 connectivity.
-
#bootstrap_broker_string_sasl_scram ⇒ String
A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs.
-
#bootstrap_broker_string_sasl_scram_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and SASL SCRAM port pairs for IPv6 connectivity.
-
#bootstrap_broker_string_tls ⇒ String
A string containing one or more DNS names (or IP addresses) and TLS port pairs.
-
#bootstrap_broker_string_tls_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and TLS port pairs for IPv6 connectivity.
-
#bootstrap_broker_string_vpc_connectivity_sasl_iam ⇒ String
A string containing one or more dns name (or IP) and SASL IAM port pairs for VPC connectivity.
-
#bootstrap_broker_string_vpc_connectivity_sasl_scram ⇒ String
A string containing one or more dns name (or IP) and SASL SCRAM port pairs for VPC connectivity.
-
#bootstrap_broker_string_vpc_connectivity_tls ⇒ String
A string containing one or more dns name (or IP) and Tls port pairs for VPC connectivity.
Instance Attribute Details
#bootstrap_broker_string ⇒ String
A string containing one or more hostname:port pairs.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and port pairs for IPv6 connectivity.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_public_sasl_iam ⇒ String
A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs. The following is an example.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_public_sasl_scram ⇒ String
A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs. The following is an example.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_public_tls ⇒ String
A string containing one or more DNS names (or IP addresses) and TLS port pairs. The following is an example.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_sasl_iam ⇒ String
A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs. The following is an example.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_sasl_iam_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and SASL IAM port pairs for IPv6 connectivity.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_sasl_scram ⇒ String
A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs. The following is an example.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_sasl_scram_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and SASL SCRAM port pairs for IPv6 connectivity.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_tls ⇒ String
A string containing one or more DNS names (or IP addresses) and TLS port pairs. The following is an example.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_tls_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and TLS port pairs for IPv6 connectivity.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_vpc_connectivity_sasl_iam ⇒ String
A string containing one or more dns name (or IP) and SASL IAM port pairs for VPC connectivity.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_vpc_connectivity_sasl_scram ⇒ String
A string containing one or more dns name (or IP) and SASL SCRAM port pairs for VPC connectivity.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_vpc_connectivity_tls ⇒ String
A string containing one or more dns name (or IP) and Tls port pairs for VPC connectivity.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 |
# File 'lib/aws-sdk-kafka/types.rb', line 2661 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |