Class: Aws::Kafka::Types::GetBootstrapBrokersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::GetBootstrapBrokersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Returns a string containing one or more hostname:port pairs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bootstrap_broker_string ⇒ String
A string containing one or more hostname:port pairs.
-
#bootstrap_broker_string_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and port pairs for IPv6 connectivity.
-
#bootstrap_broker_string_public_sasl_iam ⇒ String
A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs.
-
#bootstrap_broker_string_public_sasl_scram ⇒ String
A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs.
-
#bootstrap_broker_string_public_tls ⇒ String
A string containing one or more DNS names (or IP addresses) and TLS port pairs.
-
#bootstrap_broker_string_sasl_iam ⇒ String
A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs.
-
#bootstrap_broker_string_sasl_iam_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and SASL IAM port pairs for IPv6 connectivity.
-
#bootstrap_broker_string_sasl_scram ⇒ String
A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs.
-
#bootstrap_broker_string_sasl_scram_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and SASL SCRAM port pairs for IPv6 connectivity.
-
#bootstrap_broker_string_tls ⇒ String
A string containing one or more DNS names (or IP addresses) and TLS port pairs.
-
#bootstrap_broker_string_tls_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and TLS port pairs for IPv6 connectivity.
-
#bootstrap_broker_string_vpc_connectivity_sasl_iam ⇒ String
A string containing one or more dns name (or IP) and SASL IAM port pairs for VPC connectivity.
-
#bootstrap_broker_string_vpc_connectivity_sasl_scram ⇒ String
A string containing one or more dns name (or IP) and SASL SCRAM port pairs for VPC connectivity.
-
#bootstrap_broker_string_vpc_connectivity_tls ⇒ String
A string containing one or more dns name (or IP) and Tls port pairs for VPC connectivity.
Instance Attribute Details
#bootstrap_broker_string ⇒ String
A string containing one or more hostname:port pairs.
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and port pairs for IPv6 connectivity.
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_public_sasl_iam ⇒ String
A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs. The following is an example.
<programlisting>{ “BootstrapBrokerStringSaslIam”: “b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9198,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9198,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9198” }</programlisting>
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_public_sasl_scram ⇒ String
A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs. The following is an example.
<programlisting>{ “BootstrapBrokerStringSaslScram”: “b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9196,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9196,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9196” }</programlisting>
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_public_tls ⇒ String
A string containing one or more DNS names (or IP addresses) and TLS port pairs. The following is an example.
<programlisting>{ “BootstrapBrokerStringTls”: “b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9194,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9194,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9194” }</programlisting>
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_sasl_iam ⇒ String
A string that contains one or more DNS names (or IP addresses) and SASL IAM port pairs. The following is an example.
<programlisting>{ “BootstrapBrokerStringSaslIam”: “b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9098,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9098,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9098” }</programlisting>
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_sasl_iam_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and SASL IAM port pairs for IPv6 connectivity.
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_sasl_scram ⇒ String
A string containing one or more DNS names (or IP addresses) and SASL SCRAM port pairs. The following is an example.
<programlisting>{ “BootstrapBrokerStringSaslScram”: “b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9096,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9096,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9096” }</programlisting>
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_sasl_scram_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and SASL SCRAM port pairs for IPv6 connectivity.
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_tls ⇒ String
A string containing one or more DNS names (or IP addresses) and TLS port pairs. The following is an example.
<programlisting>{ “BootstrapBrokerStringTls”: “b-3.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9094,b-1.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9094,b-2.exampleClusterName.abcde.c2.kafka.us-east-1.amazonaws.com:9094” }</programlisting>
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_tls_ipv_6 ⇒ String
A string that contains one or more DNS names (or IP) and TLS port pairs for IPv6 connectivity.
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_vpc_connectivity_sasl_iam ⇒ String
A string containing one or more dns name (or IP) and SASL IAM port pairs for VPC connectivity.
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_vpc_connectivity_sasl_scram ⇒ String
A string containing one or more dns name (or IP) and SASL SCRAM port pairs for VPC connectivity.
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |
#bootstrap_broker_string_vpc_connectivity_tls ⇒ String
A string containing one or more dns name (or IP) and Tls port pairs for VPC connectivity.
2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/aws-sdk-kafka/types.rb', line 2345 class GetBootstrapBrokersResponse < Struct.new( :bootstrap_broker_string, :bootstrap_broker_string_public_sasl_iam, :bootstrap_broker_string_public_sasl_scram, :bootstrap_broker_string_public_tls, :bootstrap_broker_string_tls, :bootstrap_broker_string_sasl_scram, :bootstrap_broker_string_sasl_iam, :bootstrap_broker_string_vpc_connectivity_tls, :bootstrap_broker_string_vpc_connectivity_sasl_scram, :bootstrap_broker_string_vpc_connectivity_sasl_iam, :bootstrap_broker_string_ipv_6, :bootstrap_broker_string_tls_ipv_6, :bootstrap_broker_string_sasl_scram_ipv_6, :bootstrap_broker_string_sasl_iam_ipv_6) SENSITIVE = [] include Aws::Structure end |