Class: Aws::Kafka::Types::KafkaClusterDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::KafkaClusterDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Information about Kafka Cluster used as source / target for replication.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_msk_cluster ⇒ Types::AmazonMskCluster
Details of an Amazon MSK Cluster.
-
#apache_kafka_cluster ⇒ Types::ApacheKafkaCluster
Details of an Apache Kafka Cluster.
-
#client_authentication ⇒ Types::KafkaClusterClientAuthentication
Details of the client authentication used by the Apache Kafka cluster.
-
#encryption_in_transit ⇒ Types::KafkaClusterEncryptionInTransit
Details of encryption in transit to the Apache Kafka cluster.
-
#kafka_cluster_alias ⇒ String
The alias of the Kafka cluster.
-
#vpc_config ⇒ Types::KafkaClusterClientVpcConfig
Details of an Amazon VPC which has network connectivity to the Apache Kafka cluster.
Instance Attribute Details
#amazon_msk_cluster ⇒ Types::AmazonMskCluster
Details of an Amazon MSK Cluster.
2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 |
# File 'lib/aws-sdk-kafka/types.rb', line 2544 class KafkaClusterDescription < Struct.new( :amazon_msk_cluster, :apache_kafka_cluster, :kafka_cluster_alias, :vpc_config, :client_authentication, :encryption_in_transit) SENSITIVE = [] include Aws::Structure end |
#apache_kafka_cluster ⇒ Types::ApacheKafkaCluster
Details of an Apache Kafka Cluster.
2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 |
# File 'lib/aws-sdk-kafka/types.rb', line 2544 class KafkaClusterDescription < Struct.new( :amazon_msk_cluster, :apache_kafka_cluster, :kafka_cluster_alias, :vpc_config, :client_authentication, :encryption_in_transit) SENSITIVE = [] include Aws::Structure end |
#client_authentication ⇒ Types::KafkaClusterClientAuthentication
Details of the client authentication used by the Apache Kafka cluster.
2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 |
# File 'lib/aws-sdk-kafka/types.rb', line 2544 class KafkaClusterDescription < Struct.new( :amazon_msk_cluster, :apache_kafka_cluster, :kafka_cluster_alias, :vpc_config, :client_authentication, :encryption_in_transit) SENSITIVE = [] include Aws::Structure end |
#encryption_in_transit ⇒ Types::KafkaClusterEncryptionInTransit
Details of encryption in transit to the Apache Kafka cluster.
2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 |
# File 'lib/aws-sdk-kafka/types.rb', line 2544 class KafkaClusterDescription < Struct.new( :amazon_msk_cluster, :apache_kafka_cluster, :kafka_cluster_alias, :vpc_config, :client_authentication, :encryption_in_transit) SENSITIVE = [] include Aws::Structure end |
#kafka_cluster_alias ⇒ String
The alias of the Kafka cluster. Used to prefix names of replicated topics.
2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 |
# File 'lib/aws-sdk-kafka/types.rb', line 2544 class KafkaClusterDescription < Struct.new( :amazon_msk_cluster, :apache_kafka_cluster, :kafka_cluster_alias, :vpc_config, :client_authentication, :encryption_in_transit) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::KafkaClusterClientVpcConfig
Details of an Amazon VPC which has network connectivity to the Apache Kafka cluster.
2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 |
# File 'lib/aws-sdk-kafka/types.rb', line 2544 class KafkaClusterDescription < Struct.new( :amazon_msk_cluster, :apache_kafka_cluster, :kafka_cluster_alias, :vpc_config, :client_authentication, :encryption_in_transit) SENSITIVE = [] include Aws::Structure end |