Class: Aws::Kafka::Types::KafkaClusterEncryptionInTransit
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::KafkaClusterEncryptionInTransit
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Details of encryption in transit to the Apache Kafka cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_type ⇒ String
The type of encryption in transit to the Apache Kafka cluster.
-
#root_ca_certificate ⇒ String
The root CA certificate.
Instance Attribute Details
#encryption_type ⇒ String
The type of encryption in transit to the Apache Kafka cluster.
2524 2525 2526 2527 2528 2529 |
# File 'lib/aws-sdk-kafka/types.rb', line 2524 class KafkaClusterEncryptionInTransit < Struct.new( :encryption_type, :root_ca_certificate) SENSITIVE = [] include Aws::Structure end |
#root_ca_certificate ⇒ String
The root CA certificate.
2524 2525 2526 2527 2528 2529 |
# File 'lib/aws-sdk-kafka/types.rb', line 2524 class KafkaClusterEncryptionInTransit < Struct.new( :encryption_type, :root_ca_certificate) SENSITIVE = [] include Aws::Structure end |