Class: Aws::Kafka::Types::KafkaClusterEncryptionInTransit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Details of encryption in transit to the Apache Kafka cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_typeString

The type of encryption in transit to the Apache Kafka cluster.

Returns:

  • (String)


2505
2506
2507
2508
2509
2510
# File 'lib/aws-sdk-kafka/types.rb', line 2505

class KafkaClusterEncryptionInTransit < Struct.new(
  :encryption_type,
  :root_ca_certificate)
  SENSITIVE = []
  include Aws::Structure
end

#root_ca_certificateString

The root CA certificate.

Returns:

  • (String)


2505
2506
2507
2508
2509
2510
# File 'lib/aws-sdk-kafka/types.rb', line 2505

class KafkaClusterEncryptionInTransit < Struct.new(
  :encryption_type,
  :root_ca_certificate)
  SENSITIVE = []
  include Aws::Structure
end