Class: Aws::Kafka::Types::ListChannelsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ListChannelsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
-
#max_results ⇒ Integer
Maximum number of channels to return in a single response.
-
#next_token ⇒ String
If the response of ListChannels is truncated, it returns a nextToken in the response.
-
#topic_name_filter ⇒ String
Filters results to channels whose topic name matches the specified value.
Instance Attribute Details
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
3906 3907 3908 3909 3910 3911 3912 3913 |
# File 'lib/aws-sdk-kafka/types.rb', line 3906 class ListChannelsRequest < Struct.new( :cluster_arn, :max_results, :next_token, :topic_name_filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of channels to return in a single response.
3906 3907 3908 3909 3910 3911 3912 3913 |
# File 'lib/aws-sdk-kafka/types.rb', line 3906 class ListChannelsRequest < Struct.new( :cluster_arn, :max_results, :next_token, :topic_name_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response of ListChannels is truncated, it returns a nextToken in the response. This nextToken should be sent in the subsequent request to ListChannels.
3906 3907 3908 3909 3910 3911 3912 3913 |
# File 'lib/aws-sdk-kafka/types.rb', line 3906 class ListChannelsRequest < Struct.new( :cluster_arn, :max_results, :next_token, :topic_name_filter) SENSITIVE = [] include Aws::Structure end |
#topic_name_filter ⇒ String
Filters results to channels whose topic name matches the specified value.
3906 3907 3908 3909 3910 3911 3912 3913 |
# File 'lib/aws-sdk-kafka/types.rb', line 3906 class ListChannelsRequest < Struct.new( :cluster_arn, :max_results, :next_token, :topic_name_filter) SENSITIVE = [] include Aws::Structure end |