Class: Aws::Kafka::Types::ListClustersV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ListClustersV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_name_filter ⇒ String
Specify a prefix of the names of the clusters that you want to list.
-
#cluster_type_filter ⇒ String
Specify either PROVISIONED or SERVERLESS.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
The paginated results marker.
Instance Attribute Details
#cluster_name_filter ⇒ String
Specify a prefix of the names of the clusters that you want to list. The service lists all the clusters whose names start with this prefix.
3226 3227 3228 3229 3230 3231 3232 3233 |
# File 'lib/aws-sdk-kafka/types.rb', line 3226 class ListClustersV2Request < Struct.new( :cluster_name_filter, :cluster_type_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#cluster_type_filter ⇒ String
Specify either PROVISIONED or SERVERLESS.
3226 3227 3228 3229 3230 3231 3232 3233 |
# File 'lib/aws-sdk-kafka/types.rb', line 3226 class ListClustersV2Request < Struct.new( :cluster_name_filter, :cluster_type_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter.
3226 3227 3228 3229 3230 3231 3232 3233 |
# File 'lib/aws-sdk-kafka/types.rb', line 3226 class ListClustersV2Request < Struct.new( :cluster_name_filter, :cluster_type_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response. To get the next batch, provide this token in your next request.
3226 3227 3228 3229 3230 3231 3232 3233 |
# File 'lib/aws-sdk-kafka/types.rb', line 3226 class ListClustersV2Request < Struct.new( :cluster_name_filter, :cluster_type_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |