Class: Aws::Kafka::Types::ReplicatorFirehose

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafka/types.rb

Overview

Details of the Kinesis Data Firehose delivery stream that is the destination for replicator logs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delivery_streamString

The Kinesis Data Firehose delivery stream that is the destination for replicator logs.

Returns:

  • (String)


4044
4045
4046
4047
4048
4049
# File 'lib/aws-sdk-kafka/types.rb', line 4044

class ReplicatorFirehose < Struct.new(
  :delivery_stream,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Specifies whether broker logs get sent to the specified Kinesis Data Firehose delivery stream for replication.

Returns:

  • (Boolean)


4044
4045
4046
4047
4048
4049
# File 'lib/aws-sdk-kafka/types.rb', line 4044

class ReplicatorFirehose < Struct.new(
  :delivery_stream,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end