Class: Aws::Kafka::Types::S3DestinationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::S3DestinationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Configuration of an Amazon S3 destination for a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_freshness_in_seconds ⇒ Integer
The maximum time, in seconds, that records buffer in MSK before being flushed to the destination.
-
#dead_letter_queue_s3 ⇒ Types::DeadLetterQueueS3
The Amazon S3 bucket and prefix where MSK writes records that fail to deliver.
-
#service_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that MSK assumes to write to the destination Amazon S3 bucket and the dead-letter bucket.
-
#storage ⇒ Types::S3Storage
The Amazon S3 bucket, prefix, and storage class for delivered records.
Instance Attribute Details
#data_freshness_in_seconds ⇒ Integer
The maximum time, in seconds, that records buffer in MSK before being flushed to the destination. Allowed range: 300 to 900. Default: 600.
5551 5552 5553 5554 5555 5556 5557 5558 |
# File 'lib/aws-sdk-kafka/types.rb', line 5551 class S3DestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3, :service_execution_role_arn, :storage) SENSITIVE = [] include Aws::Structure end |
#dead_letter_queue_s3 ⇒ Types::DeadLetterQueueS3
The Amazon S3 bucket and prefix where MSK writes records that fail to deliver.
5551 5552 5553 5554 5555 5556 5557 5558 |
# File 'lib/aws-sdk-kafka/types.rb', line 5551 class S3DestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3, :service_execution_role_arn, :storage) SENSITIVE = [] include Aws::Structure end |
#service_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that MSK assumes to write to the destination Amazon S3 bucket and the dead-letter bucket.
5551 5552 5553 5554 5555 5556 5557 5558 |
# File 'lib/aws-sdk-kafka/types.rb', line 5551 class S3DestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3, :service_execution_role_arn, :storage) SENSITIVE = [] include Aws::Structure end |
#storage ⇒ Types::S3Storage
The Amazon S3 bucket, prefix, and storage class for delivered records.
5551 5552 5553 5554 5555 5556 5557 5558 |
# File 'lib/aws-sdk-kafka/types.rb', line 5551 class S3DestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3, :service_execution_role_arn, :storage) SENSITIVE = [] include Aws::Structure end |