Class: Aws::Kafka::Types::ServerlessConnectivityInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::ServerlessConnectivityInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Describes the cluster’s connectivity information, such as its network type, which is IPv4 or DUAL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_type ⇒ String
The network type of the cluster, which is IPv4 or DUAL.
Instance Attribute Details
#network_type ⇒ String
The network type of the cluster, which is IPv4 or DUAL. The DUAL network type uses both IPv4 and IPv6 addresses for your cluster and its resources.
By default, a cluster uses the IPv4 network type.
3235 3236 3237 3238 3239 |
# File 'lib/aws-sdk-kafka/types.rb', line 3235 class ServerlessConnectivityInfo < Struct.new( :network_type) SENSITIVE = [] include Aws::Structure end |