Class: Aws::Kafka::Types::TopicConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::TopicConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Configuration of an Apache Kafka topic that feeds a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#record_converter ⇒ Types::RecordConverter
Configuration that controls how Apache Kafka record values are deserialized for the destination.
-
#record_schema ⇒ Types::RecordSchema
The schema used to validate records when the value converter requires one (for example, JSON_SCHEMA_GSR).
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the topic.
Instance Attribute Details
#record_converter ⇒ Types::RecordConverter
Configuration that controls how Apache Kafka record values are deserialized for the destination.
5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-kafka/types.rb', line 5060 class TopicConfiguration < Struct.new( :record_converter, :record_schema, :topic_arn) SENSITIVE = [] include Aws::Structure end |
#record_schema ⇒ Types::RecordSchema
The schema used to validate records when the value converter requires one (for example, JSON_SCHEMA_GSR).
5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-kafka/types.rb', line 5060 class TopicConfiguration < Struct.new( :record_converter, :record_schema, :topic_arn) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the topic.
5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-kafka/types.rb', line 5060 class TopicConfiguration < Struct.new( :record_converter, :record_schema, :topic_arn) SENSITIVE = [] include Aws::Structure end |