Class: Aws::Kafka::Types::UpdateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kafka::Types::UpdateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafka/types.rb
Overview
Updates an existing channel's destination configuration. You must update the same destination type the channel was created with; the destination type cannot be changed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the channel.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
-
#iceberg_destination_update ⇒ Types::IcebergDestinationUpdate
Updates fields on an Apache Iceberg destination.
-
#s3_destination_update ⇒ Types::S3DestinationUpdate
Updates fields on an Amazon S3 destination.
Instance Attribute Details
#channel_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the channel.
5657 5658 5659 5660 5661 5662 5663 5664 |
# File 'lib/aws-sdk-kafka/types.rb', line 5657 class UpdateChannelRequest < Struct.new( :channel_arn, :cluster_arn, :iceberg_destination_update, :s3_destination_update) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the cluster.
5657 5658 5659 5660 5661 5662 5663 5664 |
# File 'lib/aws-sdk-kafka/types.rb', line 5657 class UpdateChannelRequest < Struct.new( :channel_arn, :cluster_arn, :iceberg_destination_update, :s3_destination_update) SENSITIVE = [] include Aws::Structure end |
#iceberg_destination_update ⇒ Types::IcebergDestinationUpdate
Updates fields on an Apache Iceberg destination. Use only when the channel was created with an Iceberg destination.
5657 5658 5659 5660 5661 5662 5663 5664 |
# File 'lib/aws-sdk-kafka/types.rb', line 5657 class UpdateChannelRequest < Struct.new( :channel_arn, :cluster_arn, :iceberg_destination_update, :s3_destination_update) SENSITIVE = [] include Aws::Structure end |
#s3_destination_update ⇒ Types::S3DestinationUpdate
Updates fields on an Amazon S3 destination. Use only when the channel was created with an Amazon S3 destination.
5657 5658 5659 5660 5661 5662 5663 5664 |
# File 'lib/aws-sdk-kafka/types.rb', line 5657 class UpdateChannelRequest < Struct.new( :channel_arn, :cluster_arn, :iceberg_destination_update, :s3_destination_update) SENSITIVE = [] include Aws::Structure end |